@@ -9,9 +9,9 @@
 
 /*******************************************************************************
  *
- * @file mss_h2f.c
+ * @file mss_m2f.c
  * @author Microchip-FPGA Embedded Systems Solutions
- * @brief H2F access data structures and functions.
+ * @brief M2F access data structures and functions.
  *
  */
 #include "mss_plic.h"
@@ -21,31 +21,29 @@
 extern "C" {
 #endif
 
-#ifndef SIFIVE_HIFIVE_UNLEASHED
-
-#define H2F_MAPPING_INVALID 255U
+#define M2F_MAPPING_INVALID 255U
 
 /*==============================================================================
- * H2F_int_mapping, source to H2F output lines
+ * M2F_int_mapping, source to M2F output lines
  * The internal interrupt are multiplexed to fabric I/O lines.
  * That is, each line will contain several interrupts.
  */
 
-const uint8_t H2F_int_mapping[BUS_ERROR_UNIT_HART_4]= { \
+const uint8_t M2F_int_mapping[PLIC_U54_4_BUS_ERROR_UNIT_OFFSET]= { \
 
-    H2F_MAPPING_INVALID /*INVALID_IRQn              = 0*/, \
-    H2F_MAPPING_INVALID /*L2_METADATA_CORR_IRQn     = 1*/, \
-    H2F_MAPPING_INVALID /*L2_METADAT_UNCORR_IRQn    = 2*/, \
-    H2F_MAPPING_INVALID /*L2_DATA_CORR_IRQn         = 3*/, \
-    H2F_MAPPING_INVALID /*L2_DATA_UNCORR_IRQn       = 4*/, \
-    H2F_MAPPING_INVALID /*DMA_CH0_DONE_IRQn         = 5*/, \
-    H2F_MAPPING_INVALID /*DMA_CH0_ERR_IRQn          = 6*/, \
-    H2F_MAPPING_INVALID /*DMA_CH1_DONE_IRQn         = 7*/, \
-    H2F_MAPPING_INVALID /*DMA_CH1_ERR_IRQn          = 8*/, \
-    H2F_MAPPING_INVALID /*DMA_CH2_DONE_IRQn         = 9*/, \
-    H2F_MAPPING_INVALID /*DMA_CH2_ERR_IRQn          = 10*/, \
-    H2F_MAPPING_INVALID /*DMA_CH3_DONE_IRQn         = 11*/, \
-    H2F_MAPPING_INVALID /*DMA_CH3_ERR_IRQn          = 12*/, \
+    M2F_MAPPING_INVALID /*INVALID_IRQn              = 0*/, \
+    M2F_MAPPING_INVALID /*L2_METADATA_CORR_IRQn     = 1*/, \
+    M2F_MAPPING_INVALID /*L2_METADAT_UNCORR_IRQn    = 2*/, \
+    M2F_MAPPING_INVALID /*L2_DATA_CORR_IRQn         = 3*/, \
+    M2F_MAPPING_INVALID /*L2_DATA_UNCORR_IRQn       = 4*/, \
+    M2F_MAPPING_INVALID /*DMA_CH0_DONE_IRQn         = 5*/, \
+    M2F_MAPPING_INVALID /*DMA_CH0_ERR_IRQn          = 6*/, \
+    M2F_MAPPING_INVALID /*DMA_CH1_DONE_IRQn         = 7*/, \
+    M2F_MAPPING_INVALID /*DMA_CH1_ERR_IRQn          = 8*/, \
+    M2F_MAPPING_INVALID /*DMA_CH2_DONE_IRQn         = 9*/, \
+    M2F_MAPPING_INVALID /*DMA_CH2_ERR_IRQn          = 10*/, \
+    M2F_MAPPING_INVALID /*DMA_CH3_DONE_IRQn         = 11*/, \
+    M2F_MAPPING_INVALID /*DMA_CH3_ERR_IRQn          = 12*/, \
 
     0x00U /*GPIO0_BIT0_or_GPIO2_BIT0_PLIC_0          = 0 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
     0x00U /*GPIO0_BIT1_or_GPIO2_BIT1_PLIC_1          = 1 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
@@ -150,90 +148,90 @@ const uint8_t H2F_int_mapping[BUS_ERROR_UNIT_HART_4]= { \
     0x05U /*WDOG3_TOUT_PLIC                          =95 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
     0x05U /*WDOG4_TOUT_PLIC                          =96 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
     0x0DU /*G5C_MSS_SPI_PLIC                         =97 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*VOLT_TEMP_ALARM_PLIC      =98 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*ATHENA_COMPLETE_PLIC      =99 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*ATHENA_ALARM_PLIC         =100 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*ATHENA_BUS_ERROR_PLIC     =101 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*VOLT_TEMP_ALARM_PLIC      =98 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*ATHENA_COMPLETE_PLIC      =99 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*ATHENA_ALARM_PLIC         =100 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*ATHENA_BUS_ERROR_PLIC     =101 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
     0x0BU /*USOC_AXIC_US_PLIC                        =102 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
     0x0BU /*USOC_AXIC_DS_PLIC                        =103 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
 
-    H2F_MAPPING_INVALID /*FABRIC_F2H_0_PLIC        = 105 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_1_PLIC        = 106 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_2_PLIC        = 107 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_3_PLIC        = 108 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_4_PLIC        = 109 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_5_PLIC        = 110 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_6_PLIC        = 111 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_7_PLIC        = 112 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_8_PLIC        = 113 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_9_PLIC        = 114 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_0_PLIC        = 105 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_1_PLIC        = 106 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_2_PLIC        = 107 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_3_PLIC        = 108 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_4_PLIC        = 109 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_5_PLIC        = 110 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_6_PLIC        = 111 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_7_PLIC        = 112 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_8_PLIC        = 113 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_9_PLIC        = 114 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
 
-    H2F_MAPPING_INVALID /*FABRIC_F2H_10_PLIC        = 115 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_11_PLIC        = 116 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_12_PLIC        = 117 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_13_PLIC        = 118 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_14_PLIC        = 119 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_15_PLIC        = 120 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_16_PLIC        = 121 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_17_PLIC        = 122 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_18_PLIC        = 123 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_19_PLIC        = 124 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_10_PLIC        = 115 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_11_PLIC        = 116 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_12_PLIC        = 117 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_13_PLIC        = 118 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_14_PLIC        = 119 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_15_PLIC        = 120 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_16_PLIC        = 121 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_17_PLIC        = 122 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_18_PLIC        = 123 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_19_PLIC        = 124 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
 
-    H2F_MAPPING_INVALID /*FABRIC_F2H_20_PLIC        = 125 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_21_PLIC        = 126 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_22_PLIC        = 127 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_23_PLIC        = 128 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_24_PLIC        = 129 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_25_PLIC        = 130 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_26_PLIC        = 131 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_27_PLIC        = 132 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_28_PLIC        = 133 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_29_PLIC        = 134 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_20_PLIC        = 125 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_21_PLIC        = 126 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_22_PLIC        = 127 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_23_PLIC        = 128 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_24_PLIC        = 129 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_25_PLIC        = 130 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_26_PLIC        = 131 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_27_PLIC        = 132 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_28_PLIC        = 133 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_29_PLIC        = 134 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
 
-    H2F_MAPPING_INVALID /*FABRIC_F2H_30_PLIC        = 135 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_31_PLIC        = 136 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_30_PLIC        = 135 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_31_PLIC        = 136 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
 
-    H2F_MAPPING_INVALID /*FABRIC_F2H_32_PLIC        = 137 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_33_PLIC        = 138 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_34_PLIC        = 139 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_35_PLIC        = 140 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_36_PLIC        = 141 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_37_PLIC        = 142 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_38_PLIC        = 143 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_39_PLIC        = 144 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_40_PLIC        = 145 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_41_PLIC        = 146 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_32_PLIC        = 137 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_33_PLIC        = 138 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_34_PLIC        = 139 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_35_PLIC        = 140 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_36_PLIC        = 141 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_37_PLIC        = 142 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_38_PLIC        = 143 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_39_PLIC        = 144 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_40_PLIC        = 145 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_41_PLIC        = 146 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
 
-    H2F_MAPPING_INVALID /*FABRIC_F2H_42_PLIC        = 147 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_43_PLIC        = 148 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_44_PLIC        = 149 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_45_PLIC        = 150 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_46_PLIC        = 151 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_47_PLIC        = 152 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_48_PLIC        = 153 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_49_PLIC        = 154 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_50_PLIC        = 155 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_51_PLIC        = 156 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_42_PLIC        = 147 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_43_PLIC        = 148 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_44_PLIC        = 149 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_45_PLIC        = 150 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_46_PLIC        = 151 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_47_PLIC        = 152 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_48_PLIC        = 153 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_49_PLIC        = 154 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_50_PLIC        = 155 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_51_PLIC        = 156 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
 
-    H2F_MAPPING_INVALID /*FABRIC_F2H_52_PLIC        = 157 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_53_PLIC        = 158 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_54_PLIC        = 159 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_55_PLIC        = 160 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_56_PLIC        = 161 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_57_PLIC        = 162 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_58_PLIC        = 163 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_59_PLIC        = 164 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_60_PLIC        = 165 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_61_PLIC        = 166 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_52_PLIC        = 157 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_53_PLIC        = 158 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_54_PLIC        = 159 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_55_PLIC        = 160 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_56_PLIC        = 161 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_57_PLIC        = 162 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_58_PLIC        = 163 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_59_PLIC        = 164 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_60_PLIC        = 165 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_61_PLIC        = 166 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
 
-    H2F_MAPPING_INVALID /*FABRIC_F2H_62_PLIC        = 167 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
-    H2F_MAPPING_INVALID /*FABRIC_F2H_63_PLIC        = 168 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_62_PLIC        = 167 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
+    M2F_MAPPING_INVALID /*MSS_INT_F2M_63_PLIC        = 168 + OFFSET_TO_MSS_GLOBAL_INTS*/, \
 
-    H2F_MAPPING_INVALID /*BUS_ERROR_UNIT_HART_0    = 182*/, \
-    H2F_MAPPING_INVALID /*BUS_ERROR_UNIT_HART_1    = 183*/, \
-    H2F_MAPPING_INVALID /*BUS_ERROR_UNIT_HART_2    = 184*/, \
-    H2F_MAPPING_INVALID /*BUS_ERROR_UNIT_HART_3    = 185*/, \
-    H2F_MAPPING_INVALID /*BUS_ERROR_UNIT_HART_4    = 186 */
+    M2F_MAPPING_INVALID /*BUS_ERROR_UNIT_HART_0    = 182*/, \
+    M2F_MAPPING_INVALID /*BUS_ERROR_UNIT_HART_1    = 183*/, \
+    M2F_MAPPING_INVALID /*BUS_ERROR_UNIT_HART_2    = 184*/, \
+    M2F_MAPPING_INVALID /*BUS_ERROR_UNIT_HART_3    = 185*/, \
+    M2F_MAPPING_INVALID /*BUS_ERROR_UNIT_HART_4    = 186 */
 
 };
 
@@ -243,29 +241,29 @@ const uint8_t H2F_int_mapping[BUS_ERROR_UNIT_HART_4]= { \
  * @param source_int
  * @return
  */
-static uint32_t get_corresponding_h2f_output(uint32_t source_int)
+static uint32_t get_corresponding_m2f_output(uint32_t source_int)
 {
-    uint32_t h2f_line = H2F_int_mapping[source_int];
+    uint32_t m2f_line = M2F_int_mapping[source_int];
 
-    if(h2f_line < H2F_MAPPING_INVALID) /* if no error */
+    if(m2f_line < M2F_MAPPING_INVALID) /* if no error */
     {
-        return(0x01U << h2f_line);
+        return(0x01U << m2f_line);
     }
 
-    return(h2f_line);
+    return(m2f_line);
 
 }
 
 /**
- * set H2F controller to reset to defaults- disabled
+ * set M2F controller to reset to defaults- disabled
  */
-void reset_h2f(void)
+void reset_m2f(void)
 {
     uint8_t index = 0U;
-    H2F_CONTROLLER->ENABLE = 0U;
+    M2F_CONTROLLER->ENABLE = 0U;
     while(index < 4U)
     {
-        H2F_CONTROLLER->PLENABLE[index] = 0U;
+        M2F_CONTROLLER->PLENABLE[index] = 0U;
         index++;
     }
 }
@@ -274,20 +272,20 @@ void reset_h2f(void)
  * enables output which will mirror PLIC input. PLIC mapping given above for reference
  * @param source_int
  */
-void enable_h2f_int_output(uint32_t source_int)
+void enable_m2f_int_output(uint32_t source_int)
 {
 
-    uint32_t output_signal = get_corresponding_h2f_output(source_int);
+    uint32_t output_signal = get_corresponding_m2f_output(source_int);
 
-    if(output_signal != H2F_MAPPING_INVALID)
+    if(output_signal != M2F_MAPPING_INVALID)
     {
         source_int -= OFFSET_TO_MSS_GLOBAL_INTS;
 
         /* enable the input */
-        H2F_CONTROLLER->PLENABLE[source_int/32U] |= (0x01U << (source_int % 32U));
+        M2F_CONTROLLER->PLENABLE[source_int/32U] |= (0x01U << (source_int % 32U));
 
         /* enable the output */
-        H2F_CONTROLLER->ENABLE |= ((output_signal<<16U) | 0x01U);
+        M2F_CONTROLLER->ENABLE |= ((output_signal<<16U) | 0x01U);
     }
 }
 
@@ -296,16 +294,16 @@ void enable_h2f_int_output(uint32_t source_int)
  * enables output which will mirror PLIC input. PLIC mapping given above for reference
  * @param source_int
  */
-void disable_h2f_int_output(uint32_t source_int)
+void disable_m2f_int_output(uint32_t source_int)
 {
-    uint32_t output_signal = get_corresponding_h2f_output(source_int);
+    uint32_t output_signal = get_corresponding_m2f_output(source_int);
 
-    if(output_signal != H2F_MAPPING_INVALID)
+    if(output_signal != M2F_MAPPING_INVALID)
     {
         /* enable the input */
-        H2F_CONTROLLER->PLENABLE[source_int/32U] &= ~(source_int % 32U);
+        M2F_CONTROLLER->PLENABLE[source_int/32U] &= ~(source_int % 32U);
         /* enable the output */
-        H2F_CONTROLLER->ENABLE &= ~(((output_signal<<16U)));
+        M2F_CONTROLLER->ENABLE &= ~(((output_signal<<16U)));
     }
 }
 
@@ -313,7 +311,4 @@ void disable_h2f_int_output(uint32_t source_int)
 }
 #endif
 
-#endif
-
-
 
