@@ -17,6 +17,11 @@
 #include <stdio.h>
 
 #include "mpfs_hal/mss_hal.h"
+#ifdef LIBERO_SETTING_ALT_IOMUX1_CR
+#if ((LIBERO_SETTING_MSSIO_CONFIGURATION_OPTIONS & (EMMC_CONFIGURED_MASK | SD_CONFIGURED_MASK)) == (EMMC_CONFIGURED_MASK | SD_CONFIGURED_MASK))
+static uint8_t io_mux_and_bank_config_alt(void);
+#endif
+#endif
 
 /*******************************************************************************
  * external functions
@@ -554,7 +559,8 @@ __attribute__((weak)) uint8_t switch_external_mux(MSS_IO_OPTIONS option)
 {
     uint8_t result = false;
 
-    volatile uint32_t *reg_pt = (uint32_t *)ICICLE_KIT_REF_DESIGN_FPGS_SWITCH_ADDRESS;
+#ifdef LIBERO_SETTING_FPGA_SWITCH_ADDRESS
+    volatile uint32_t *reg_pt = (uint32_t *)LIBERO_SETTING_FPGA_SWITCH_ADDRESS;
     switch(option)
     {
         case SD_MSSIO_CONFIGURATION:
@@ -571,14 +577,33 @@ __attribute__((weak)) uint8_t switch_external_mux(MSS_IO_OPTIONS option)
         case NOT_SETUP_MSSIO_CONFIGURATION:
             break;
     }
+#endif
+
     result = true;
 
     return result;
 }
 
 
+/***************************************************************************//**
+ * See mss_io_config.h for details of how to use this function.
+ */
+__attribute__((weak)) void mss_set_gpio_interrupt_fab_cr(uint32_t reg_value)
+{
+    SYSREG->GPIO_INTERRUPT_FAB_CR = reg_value;
+}
+
+/***************************************************************************//**
+ * See mss_peripherals.h for details of how to use this function.
+ */
+__attribute__((weak)) uint32_t mss_get_gpio_interrupt_fab_cr(void)
+{
+    return (SYSREG->GPIO_INTERRUPT_FAB_CR);
+}
+
+
 #ifdef EXAMPLE_MSSIO_APP_CODE
-#include "drivers/mss/mss_gpio/mss_gpio.h"
+#include "drivers/mss_gpio/mss_gpio.h"
 /**
  *
  * @return 0 => OK
