@@ -32,13 +32,14 @@
 #include "mpfs_hal/mss_hal.h"
 #ifdef  MPFS_HAL_HW_CONFIG
 #include "../common/nwc/mss_nwc_init.h"
-#include "system_startup_defs.h"
 #endif
+#include "system_startup_defs.h"
 
 
 /*==============================================================================
  * This function is called by the lowest enabled hart (MPFS_HAL_FIRST_HART) in
- * the configuration file (platform/config/software/mpfs_hal/mss_sw_config.h )
+ * the configuration file :
+ * (src/boards/<my-board/platform_config/mpfs_hal_config/mss_sw_config.h )
  *
  * The other harts up to MPFS_HAL_LAST_HART are placed in wfi at this point.
  * This function brings them out of wfi in sequence.
@@ -46,6 +47,7 @@
  * space
  * e.g. /hart0/e51.c
  */
+#if (IMAGE_LOADED_BY_BOOTLOADER == 0)
 __attribute__((weak)) int main_first_hart(HLS_DATA* hls)
 {
     uint64_t hartid = read_csr(mhartid);
@@ -60,7 +62,7 @@ __attribute__((weak)) int main_first_hart(HLS_DATA* hls)
          * #ifdef MPFS_HAL_HW_CONFIG
          * if this program is used as part of the initial board bring-up
          * Please comment/uncomment MPFS_HAL_HW_CONFIG define in
-         * platform/config/software/mpfs_hal/sw_config.h
+         * src/boards/<my-board/platform_config/mpfs_hal_config/sw_config.h
          * as required.
          */
 #ifdef  MPFS_HAL_HW_CONFIG
@@ -77,6 +79,7 @@ __attribute__((weak)) int main_first_hart(HLS_DATA* hls)
         (void)init_mem_protection_unit();
         (void)init_pmp((uint8_t)MPFS_HAL_FIRST_HART);
         (void)mss_set_apb_bus_cr((uint32_t)LIBERO_SETTING_APBBUS_CR);
+        (void)mss_set_gpio_interrupt_fab_cr((uint32_t)LIBERO_SETTING_GPIO_INTERRUPT_FAB_CR);
 #endif  /* MPFS_HAL_HW_CONFIG */
         /*
          * Initialise NWC
@@ -87,6 +90,7 @@ __attribute__((weak)) int main_first_hart(HLS_DATA* hls)
          */
 #ifdef  MPFS_HAL_HW_CONFIG
         (void)mss_nwc_init();
+        (void)mss_nwc_init_ddr();
 
         /* main hart init's the PLIC */
         PLIC_init_on_reset();
@@ -180,11 +184,14 @@ __attribute__((weak)) int main_first_hart(HLS_DATA* hls)
         (void)mss_config_clk_rst(MSS_PERIPH_FIC1, (uint8_t)MPFS_HAL_FIRST_HART, PERIPHERAL_ON);
         (void)mss_config_clk_rst(MSS_PERIPH_FIC2, (uint8_t)MPFS_HAL_FIRST_HART, PERIPHERAL_ON);
         (void)mss_config_clk_rst(MSS_PERIPH_FIC3, (uint8_t)MPFS_HAL_FIRST_HART, PERIPHERAL_ON);
+        /* enable the fabric */
+        mss_enable_fabric();
 
 #endif /* MPFS_HAL_HW_CONFIG */
         (void)main_other_hart(hls);
     }
 
+    __builtin_unreachable();
     /* should never get here */
     while(true)
     {
@@ -195,66 +202,110 @@ __attribute__((weak)) int main_first_hart(HLS_DATA* hls)
 
     return (0);
 }
+#endif
 
 /*==============================================================================
- * u54_single_hart startup.
- * This is called when a bootloader has loaded a single hart program.
- * A pointer to the hart Local Storage (HLS) is passed here which has been
- * passed by the boot program in the a1 register.
- * The HLS contains the hartID.
- * It also contains a pointer to shared memory
- * Information on the HLS used in the bare metal examples.
- *           The HLS is a small amount of memory dedicated to each hart.
- *           The HLS also contains a pointer to shared memory.
- *           The shared memory is accessible by all harts if used. It is
- *           allocated by the boot-loader if the MPFS_HAL_SHARED_MEM_ENABLED
- *           is defined in the mss_sw_config.h file project configuration file.
- * Please see the project mpfs-hal-run-from-ddr-u54-1 located in the Bare Metal
- * library under examples/mpfs-hal for an example of it use.
- *
- * https://github.com/polarfire-soc/polarfire-soc-bare-metal-library
+ * This function is called by the lowest enabled hart (MPFS_HAL_FIRST_HART) in
+ * the configuration file :
+ * (src/boards/<my-board/platform_config/mpfs_hal_config/mss_sw_config.h )
  *
+ * The other harts up to MPFS_HAL_LAST_HART are placed in wfi at this point.
+ * This function brings them out of wfi in sequence.
  * If you need to modify this function, create your own one in a user directory
  * space
- * e.g. /hart1/x.c
+ * e.g. /hart0/e51.c
  */
-int u54_single_hart(HLS_DATA* hls);
-__attribute__((weak)) int u54_single_hart(HLS_DATA* hls)
+#if (IMAGE_LOADED_BY_BOOTLOADER == 1)
+
+__attribute__((weak)) int main_first_hart_app(HLS_DATA* hls)
 {
-    init_memory();
-    hls->my_hart_id = MPFS_HAL_FIRST_HART;
-#ifdef  MPFS_HAL_SHARED_MEM_ENABLED
-    /* if shared memory enabled, pointer from Boot-loader in the HLS should be
-     * non-zero */
-    ASSERT(hls->shared_mem != NULL);
-#endif
-    switch(hls->my_hart_id)
+    uint64_t hartid = read_csr(mhartid);
+
+    if(hartid == MPFS_HAL_FIRST_HART)
     {
-        case 0U:
-            e51();
-            break;
+        uint8_t hart_id;
+        ptrdiff_t stack_top;
 
-        case 1U:
-            u54_1();
-            break;
+        init_memory();
 
-        case 2U:
-            u54_2();
-            break;
+        hls->my_hart_id = MPFS_HAL_FIRST_HART;
+        hls->in_wfi_indicator = HLS_MAIN_HART_STARTED;
+        WFI_SM sm_check_thread = INIT_THREAD_PR;
+        hart_id = MPFS_HAL_FIRST_HART + 1U;
+        while( hart_id <= MPFS_HAL_LAST_HART)
+        {
+            uint32_t wait_count = 0U;
 
-        case 3U:
-            u54_3();
-            break;
+            switch(sm_check_thread)
+            {
+                default:
+                case INIT_THREAD_PR:
 
-        case 4U:
-            u54_4();
-            break;
+                    switch (hart_id)
+                    {
+                        case 1:
+                            stack_top = (ptrdiff_t)((uint8_t*)&__stack_top_h1$);
+                            break;
+                        case 2:
+                            stack_top = (ptrdiff_t)((uint8_t*)&__stack_top_h2$);
+                            break;
+                        case 3:
+                            stack_top = (ptrdiff_t)((uint8_t*)&__stack_top_h3$);
+                            break;
+                        case 4:
+                            stack_top = (ptrdiff_t)((uint8_t*)&__stack_top_h4$);
+                            break;
+                    }
+                    hls = (HLS_DATA*)(stack_top - HLS_DEBUG_AREA_SIZE);
+                    sm_check_thread = CHECK_WFI;
+                    wait_count = 0U;
+                    break;
 
-        default:
-            /* no more harts */
-            break;
+                case CHECK_WFI:
+                    if( hls->in_wfi_indicator == HLS_OTHER_HART_IN_WFI )
+                    {
+                        /* Separate state- to add a little delay */
+                        sm_check_thread = SEND_WFI;
+                    }
+                    break;
+
+                case SEND_WFI:
+                    hls->my_hart_id = hart_id; /* record hartid locally */
+                    raise_soft_interrupt(hart_id);
+                    sm_check_thread = CHECK_WAKE;
+                    wait_count = 0UL;
+                    break;
+
+                case CHECK_WAKE:
+                    if( hls->in_wfi_indicator == HLS_OTHER_HART_PASSED_WFI )
+                    {
+                        sm_check_thread = INIT_THREAD_PR;
+                        hart_id++;
+                        wait_count = 0UL;
+                    }
+                    else
+                    {
+                        wait_count++;
+                        if(wait_count > 0x10U)
+                        {
+                            if( hls->in_wfi_indicator == HLS_OTHER_HART_IN_WFI )
+                            {
+                                hls->my_hart_id = hart_id; /* record hartid locally */
+                                raise_soft_interrupt(hart_id);
+                                wait_count = 0UL;
+                            }
+                        }
+                    }
+                    break;
+            }
+        }
+        stack_top = (ptrdiff_t)((uint8_t*)&__stack_top_h1$);
+        hls = (HLS_DATA*)(stack_top - HLS_DEBUG_AREA_SIZE);
+        hls->in_wfi_indicator = HLS_MAIN_HART_FIN_INIT;
+        (void)main_other_hart(hls);
     }
 
+    __builtin_unreachable();
     /* should never get here */
     while(true)
     {
@@ -265,6 +316,7 @@ __attribute__((weak)) int u54_single_hart(HLS_DATA* hls)
 
     return (0);
 }
+#endif
 
 /*==============================================================================
  * U54s startup.
@@ -281,7 +333,7 @@ __attribute__((weak)) int u54_single_hart(HLS_DATA* hls)
  */
 __attribute__((weak)) int main_other_hart(HLS_DATA* hls)
 {
-#ifdef  MPFS_HAL_HW_CONFIG
+#if (IMAGE_LOADED_BY_BOOTLOADER == 0)   // This also means no hardware init is required
     extern char __app_stack_top_h0;
     extern char __app_stack_top_h1;
     extern char __app_stack_top_h2;
@@ -366,7 +418,40 @@ __attribute__((weak)) int main_other_hart(HLS_DATA* hls)
        /* Added some code as debugger hangs if in loop doing nothing */
        counter = counter + 1U;
     }
+#else /* (IMAGE_LOADED_BY_BOOTLOADER == 0) */
+
+
+    uint64_t hartid = read_csr(mhartid);
+
+    switch(hartid)
+    {
+
+    case 0U:
+        e51();
+        break;
+
+    case 1U:
+        u54_1();
+        break;
+
+    case 2U:
+        u54_2();
+        break;
+
+    case 3U:
+        u54_3();
+        break;
+
+    case 4U:
+        u54_4();
+        break;
+
+    default:
+        /* no more harts */
+        break;
+    }
 #endif
+
   return (0);
 
 }
@@ -524,7 +609,6 @@ __attribute__((weak)) void u54_4(void)
 
 __attribute__((weak)) uint8_t init_bus_error_unit(void)
 {
-#ifndef SIFIVE_HIFIVE_UNLEASHED
     uint8_t hart_id;
     /* Init BEU in all harts - enable local interrupt */
     for(hart_id = MPFS_HAL_FIRST_HART; hart_id <= MPFS_HAL_LAST_HART; hart_id++)
@@ -536,7 +620,6 @@ __attribute__((weak)) uint8_t init_bus_error_unit(void)
         BEU->regs[hart_id].ACCRUED     = 0ULL;
         BEU->regs[hart_id].VALUE       = 0ULL;
     }
-#endif
     return (0U);
 }
 
@@ -547,9 +630,7 @@ __attribute__((weak)) uint8_t init_bus_error_unit(void)
  */
 __attribute__((weak)) uint8_t init_mem_protection_unit(void)
 {
-#ifndef SIFIVE_HIFIVE_UNLEASHED
     mpu_configure();
-#endif
     return (0U);
 }
 
@@ -564,23 +645,4 @@ __attribute__((weak)) uint8_t init_pmp(uint8_t hart_id)
     return (0U);
 }
 
-/**
- * set_apb_bus_cr(void)
- * todo: add check to see if value valid re. mss configurator
- * @return
- */
-__attribute__((weak)) uint8_t mss_set_apb_bus_cr(uint32_t reg_value)
-{
-    SYSREG->APBBUS_CR = reg_value;
-    return (0U);
-}
-
-/**
- * get_apb_bus_cr(void)
- * @return
- */
-__attribute__((weak)) uint8_t mss_get_apb_bus_cr(void)
-{
-    return (SYSREG->APBBUS_CR);
-}
 
