@@ -47,7 +47,6 @@
 
 #include "hss_state_machine.h"
 #include "hss_debug.h"
-#include "hss_crc32.h"
 #include "hss_perfctr.h"
 
 #include <string.h>
@@ -67,12 +66,15 @@
 //
 // local module functions
 
-static inline bool verifyMagic_(struct HSS_BootImage const * const pBootImage);
-
-#if !IS_ENABLED(CONFIG_SERVICE_BOOT_USE_PAYLOAD)
+#if IS_ENABLED(CONFIG_SERVICE_BOOT)
+#  if !IS_ENABLED(CONFIG_SERVICE_BOOT_USE_PAYLOAD)
 typedef bool (*HSS_BootImageCopyFnPtr_t)(void *pDest, size_t srcOffset, size_t byteCount);
 static bool copyBootImageToDDR_(struct HSS_BootImage *pBootImage, char *pDest,
     size_t srcOffset, HSS_BootImageCopyFnPtr_t pCopyFunction);
+#  endif
+
+static void printBootImageDetails_(struct HSS_BootImage const * const pBootImage);
+static bool tryBootFunction_(struct HSS_Storage *pStorage, HSS_GetBootImageFnPtr_t getBootImageFunction);
 #endif
 
 static bool getBootImageFromQSPI_(struct HSS_Storage *pStorage, struct HSS_BootImage **ppBootImage);
@@ -80,9 +82,6 @@ static bool getBootImageFromMMC_(struct HSS_Storage *pStorage, struct HSS_BootIm
 static bool getBootImageFromSpiFlash_(struct HSS_Storage *pStorage, struct HSS_BootImage **ppBootImage);
 static bool getBootImageFromPayload_(struct HSS_Storage *pStorage, struct HSS_BootImage **ppBootImage);
 
-static void printBootImageDetails_(struct HSS_BootImage const * const pBootImage);
-static bool validateCrc_(struct HSS_BootImage *pImage);
-static bool tryBootFunction_(struct HSS_Storage *pStorage, HSS_GetBootImageFnPtr_t getBootImageFunction);
 
 //
 //
@@ -137,12 +136,12 @@ static struct HSS_Storage *pStorages[] =
 #if IS_ENABLED(CONFIG_SERVICE_QSPI)
 	&qspiStorage_,
 #endif
-#if IS_ENABLED(CONFIG_SERVICE_MMC)
-	&mmcStorage_,
-#endif
 #if IS_ENABLED(CONFIG_SERVICE_SPI)
 	&spiStorage_,
 #endif
+#if IS_ENABLED(CONFIG_SERVICE_MMC)
+	&mmcStorage_,
+#endif
 #if IS_ENABLED(CONFIG_SERVICE_BOOT_USE_PAYLOAD)
 	&payloadStorage_,
 #endif
@@ -168,14 +167,21 @@ struct HSS_Storage *HSS_BootGetActiveStorage(void)
     }
 
     return pResult;
+}
 
+void HSS_BootListStorageProviders(void)
+{
+    for (uint32_t i = 0; i < ARRAY_SIZE(pStorages); i++) {
+        mHSS_DEBUG_PRINTF_EX(" - %s\n", pStorages[i]->name);
+    }
 }
 
 bool HSS_BootInit(void)
 {
-    bool result = false;
+    bool result = true;
+#if IS_ENABLED(CONFIG_SERVICE_BOOT)
 
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Initializing Boot Image ..." CRLF);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Initializing Boot Image ...\n");
 
     int perf_ctr_index = PERF_CTR_UNINITIALIZED;
     HSS_PerfCtr_Allocate(&perf_ctr_index, "Boot Image Init");
@@ -187,8 +193,14 @@ bool HSS_BootInit(void)
         }
     } else {
         for (int i = 0; i < ARRAY_SIZE(pStorages); i++) {
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "Trying to boot via %s ..." CRLF, pStorages[i]->name);
-            result = pStorages[i]->init();
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "Trying to boot via %s ...\n", pStorages[i]->name);
+
+            if (pStorages[i]->init) {
+                result = pStorages[i]->init();
+            } else {
+                result = true;
+            }
+
             if (result) {
                 result = tryBootFunction_(pStorages[i], pStorages[i]->getBootImage);
                 if (result) { break; }
@@ -197,39 +209,44 @@ bool HSS_BootInit(void)
     }
 
     HSS_PerfCtr_Lap(perf_ctr_index);
+#endif
+
     return result;
 }
 
+#if IS_ENABLED(CONFIG_SERVICE_BOOT)
 bool tryBootFunction_(struct HSS_Storage *pStorage, HSS_GetBootImageFnPtr_t const bootImageFunction)
 {
     bool result = false;
-    bool decompressedFlag = false;
-    struct HSS_BootImage *pBootImage = NULL;
-
     (void)pStorage;
 
-#if IS_ENABLED(CONFIG_SERVICE_BOOT)
+    struct HSS_BootImage *pBootImage = NULL;
+    bool decompressedFlag = false;
+
+    (void)decompressedFlag;
+
+
     result = bootImageFunction(pStorage, &pBootImage);
     //
     // check if this image is compressed...
     // if so, decompress it to DDR
     //
-    // for now, compression only works with a source already in DDR 
+    // for now, compression only works with a source already in DDR
 #  if IS_ENABLED(CONFIG_COMPRESSION)
     if (result && pBootImage->magic == mHSS_COMPRESSED_MAGIC) {
         decompressedFlag = true;
         if (!result) {
-            mHSS_DEBUG_PRINTF(LOG_ERROR, "Failed to get boot image, cannot decompress" CRLF);
+            mHSS_DEBUG_PRINTF(LOG_ERROR, "Failed to get boot image, cannot decompress\n");
         } else if (!pBootImage) {
-            mHSS_DEBUG_PRINTF(LOG_ERROR, "Boot Image NULL, ignoring" CRLF);
+            mHSS_DEBUG_PRINTF(LOG_ERROR, "Boot Image NULL, ignoring\n");
             result = false;
         } else {
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "Preparing to decompress to DDR ..." CRLF);
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "Preparing to decompress to DDR ...\n");
             void* const pInput = (void*)pBootImage;
             void * const pOutputInDDR = (void *)(CONFIG_SERVICE_BOOT_DDR_TARGET_ADDR);
 
             int outputSize = HSS_Decompress(pInput, pOutputInDDR);
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "decompressed %d bytes ..." CRLF, outputSize);
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "decompressed %d bytes ...\n", outputSize);
 
             if (outputSize) {
                 pBootImage = (struct HSS_BootImage *)pOutputInDDR;
@@ -240,96 +257,27 @@ bool tryBootFunction_(struct HSS_Storage *pStorage, HSS_GetBootImageFnPtr_t cons
     }
 #  endif
 
-    //
-    // now have a Full Boot Image, let's check it is a valid one...
-    //
-    {
-        if (!pBootImage) {
-            mHSS_DEBUG_PRINTF(LOG_ERROR, "Boot Image NULL, ignoring" CRLF);
-            result = false;
-        } else if (pBootImage->magic != mHSS_BOOT_MAGIC) {
-            mHSS_DEBUG_PRINTF(LOG_ERROR, "Boot Image magic invalid, ignoring" CRLF);
-            result = false;
-#  if IS_ENABLED(CONFIG_CRYPTO_SIGNING)
-        } else if (!HSS_Boot_Secure_CheckCodeSigning(pBootImage)) {
-            mHSS_DEBUG_PRINTF(LOG_ERROR, "Boot Image failed code signing" CRLF);
-            result = false;
-#  endif
-        } else if (validateCrc_(pBootImage)) {
-            mHSS_DEBUG_PRINTF(LOG_STATUS, "Boot image passed CRC" CRLF,
-                decompressedFlag ? "decompressed":"");
-
-        // GCC 9.x appears to dislike the pBootImage cast, and sees dereferencing the
-        // set name as an out-of-bounds... So we'll disable that warning just for
-        // this print...
-#  pragma GCC diagnostic push
-#  pragma GCC diagnostic ignored "-Warray-bounds"
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "Boot image set name: \"%s\"" CRLF, pBootImage->set_name);
-#  pragma GCC diagnostic pop
-            HSS_Register_Boot_Image(pBootImage);
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "Boot Image registered ..." CRLF);
-
-#  if defined(CONFIG_SERVICE_BOOT_CUSTOM_FLOW)
-            result = HSS_Boot_Custom();
-#  else
-            result = true;
-#  endif
-        } else {
-            mHSS_DEBUG_PRINTF(LOG_ERROR, "Boot image failed CRC" CRLF,
-                decompressedFlag ? "decompressed":"");
-        }
+    if (result) {
+        HSS_Register_Boot_Image(pBootImage);
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s: Boot Image registered ...\n", pStorage->name);
     }
-#endif
 
     return result;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////
 
-static bool validateCrc_(struct HSS_BootImage *pImageHdr)
-{
-    bool result = false;
-    uint32_t headerCrc;
-
-    struct HSS_BootImage shadowHdr = *pImageHdr;
-
-    shadowHdr.headerCrc = 0u;
-    memset(&(shadowHdr.signature), 0, sizeof(shadowHdr.signature));
-
-    size_t crcLen;
-    switch (pImageHdr->version) {
-    case 0u:
-        // pre crypto-signing, the BootImage format was slightly different, so to ensure
-        // no CRC failures on older images, we use a legacy structure size...
-        crcLen = sizeof(struct HSS_BootImage_v0);
-        break;
-
-    default:
-        crcLen = sizeof(struct HSS_BootImage);
-        break;
-    }
-
-    headerCrc = CRC32_calculate((const uint8_t *)&shadowHdr, crcLen);
-    if (headerCrc == pImageHdr->headerCrc) {
-        result = true;
-    } else {
-        mHSS_DEBUG_PRINTF(LOG_ERROR, "Checked HSS_BootImage header CRC (%p->%p): calculated %08x vs expected %08x" CRLF,
-            pImageHdr, (char *)pImageHdr + sizeof(struct HSS_BootImage), headerCrc, pImageHdr->headerCrc);
-    }
-
-    return result;
-}
-
 static void printBootImageDetails_(struct HSS_BootImage const * const pBootImage)
 {
-#ifdef BOOT_DEBUG
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, " - set name is >>%s<<" CRLF, pBootImage->set_name);
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, " - magic is    %08x" CRLF, pBootImage->magic);
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, " - length is   %08x" CRLF, pBootImage->bootImageLength);
-#endif
+#  ifdef BOOT_DEBUG
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, " - set name is >>%s<<\n", pBootImage->set_name);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, " - magic is    %08x\n", pBootImage->magic);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, " - length is   %08x\n", pBootImage->bootImageLength);
+#  endif
 }
+#endif
 
-#if !IS_ENABLED(CONFIG_SERVICE_BOOT_USE_PAYLOAD)
+#if IS_ENABLED(CONFIG_SERVICE_BOOT) && !IS_ENABLED(CONFIG_SERVICE_BOOT_USE_PAYLOAD)
 static bool copyBootImageToDDR_(struct HSS_BootImage *pBootImage, char *pDest,
     size_t srcOffset, HSS_BootImageCopyFnPtr_t pCopyFunction)
 {
@@ -337,7 +285,7 @@ static bool copyBootImageToDDR_(struct HSS_BootImage *pBootImage, char *pDest,
 
     printBootImageDetails_(pBootImage);
 
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Copying %lu bytes to 0x%lx" CRLF,
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Copying %lu bytes to 0x%lx\n",
         pBootImage->bootImageLength, pDest);
     result = pCopyFunction(pDest, srcOffset, pBootImage->bootImageLength);
 
@@ -345,30 +293,16 @@ static bool copyBootImageToDDR_(struct HSS_BootImage *pBootImage, char *pDest,
 }
 #endif
 
-static inline bool verifyMagic_(struct HSS_BootImage const * const pBootImage)
-{
-    bool result = false;
-
-    if ((pBootImage->magic == mHSS_BOOT_MAGIC) || (pBootImage->magic == mHSS_COMPRESSED_MAGIC)) {
-        result = true;
-    } else {
-        mHSS_DEBUG_PRINTF(LOG_ERROR, "magic is %08x vs expected %08x or %08x" CRLF,
-            pBootImage->magic, mHSS_BOOT_MAGIC, mHSS_COMPRESSED_MAGIC);
-    }
-
-    return result;
-}
-
 static bool getBootImageFromMMC_(struct HSS_Storage *pStorage, struct HSS_BootImage **ppBootImage)
 {
     bool result = false;
 
-#if IS_ENABLED(CONFIG_SERVICE_MMC)
+#if IS_ENABLED(CONFIG_SERVICE_BOOT) && IS_ENABLED(CONFIG_SERVICE_MMC)
     assert(ppBootImage);
 
     // if we are using MMC, then we need to do an initial copy of the
     // boot header into our structure, for subsequent use
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Preparing to copy from MMC to DDR ..." CRLF);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Preparing to copy from MMC to DDR ...\n");
 
     size_t srcLBAOffset = 0u;
     assert(pStorage);
@@ -388,14 +322,14 @@ static bool getBootImageFromMMC_(struct HSS_Storage *pStorage, struct HSS_BootIm
             size_t srcIndex = 0u;
 
             if (GPT_GetBootPartitionIndex(&gpt, &srcIndex)) {
-                mHSS_DEBUG_PRINTF(LOG_WARN, "Using manually set partition index" CRLF);
+                mHSS_DEBUG_PRINTF(LOG_WARN, "Using manually set partition index\n");
             } else {
                 result = GPT_FindBootSectorIndex(&gpt, &srcIndex, NULL);
 
                 if (!result) {
-                    mHSS_DEBUG_PRINTF(LOG_ERROR, "GPT_FindBootSectorIndex() failed" CRLF);
+                    mHSS_DEBUG_PRINTF(LOG_ERROR, "GPT_FindBootSectorIndex() failed\n");
                 } else {
-                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Boot Partition found at index %lu" CRLF,
+                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Boot Partition found at index %lu\n",
                         srcIndex);
                 }
             }
@@ -407,9 +341,9 @@ static bool getBootImageFromMMC_(struct HSS_Storage *pStorage, struct HSS_BootIm
     }
 
     if (!result) {
-        mHSS_DEBUG_PRINTF(LOG_WARN, "GPT_PartitionIdToLBAOffset() failed - using offset %lu" CRLF, srcLBAOffset);
+        mHSS_DEBUG_PRINTF(LOG_WARN, "GPT_PartitionIdToLBAOffset() failed - using offset %lu\n", srcLBAOffset);
     } else {
-        //mHSS_DEBUG_PRINTF(LOG_WARN, "GPT_PartitionIdToLBAOffset() returned %lu" CRLF, srcLBAOffset);
+        //mHSS_DEBUG_PRINTF(LOG_WARN, "GPT_PartitionIdToLBAOffset() returned %lu\n", srcLBAOffset);
     }
 #endif
 
@@ -417,18 +351,18 @@ static bool getBootImageFromMMC_(struct HSS_Storage *pStorage, struct HSS_BootIm
     // Even if we have GPT enabled and it fails to find a GPT parttion, we'll still
     // try to boot
     {
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Attempting to read image header (%d bytes) ..." CRLF,
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Attempting to read image header (%d bytes) ...\n",
             sizeof(struct HSS_BootImage));
         result = HSS_MMC_ReadBlock(&bootImage, srcLBAOffset * blockSize,
             sizeof(struct HSS_BootImage));
 
         if (!result) {
-            mHSS_DEBUG_PRINTF(LOG_ERROR, "HSS_MMC_ReadBlock() failed" CRLF);
+            mHSS_DEBUG_PRINTF(LOG_ERROR, "HSS_MMC_ReadBlock() failed\n");
         } else {
-            result = verifyMagic_(&bootImage);
+            result = HSS_Boot_VerifyMagic(&bootImage);
 
             if (!result) {
-                mHSS_DEBUG_PRINTF(LOG_ERROR, "verifyMagic_() failed" CRLF);
+                mHSS_DEBUG_PRINTF(LOG_ERROR, "HSS_Boot_VerifyMagic() failed\n");
             } else {
                 int perf_ctr_index = PERF_CTR_UNINITIALIZED;
                 HSS_PerfCtr_Allocate(&perf_ctr_index, "Boot Image MMC Copy");
@@ -441,7 +375,7 @@ static bool getBootImageFromMMC_(struct HSS_Storage *pStorage, struct HSS_BootIm
                 HSS_PerfCtr_Lap(perf_ctr_index);
 
                 if (!result) {
-                     mHSS_DEBUG_PRINTF(LOG_ERROR, "copyBootImageToDDR_() failed" CRLF);
+                     mHSS_DEBUG_PRINTF(LOG_ERROR, "copyBootImageToDDR_() failed\n");
                 }
             }
         }
@@ -454,7 +388,7 @@ static bool getBootImageFromMMC_(struct HSS_Storage *pStorage, struct HSS_BootIm
 void HSS_BootSelectMMC(void)
 {
 #if IS_ENABLED(CONFIG_SERVICE_MMC)
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Selecting MMC as boot source ..." CRLF);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Selecting MMC as boot source ...\n");
     pDefaultStorage = &mmcStorage_;
 #else
     (void)getBootImageFromMMC_;
@@ -465,11 +399,11 @@ static bool getBootImageFromQSPI_(struct HSS_Storage *pStorage, struct HSS_BootI
 {
     bool result = false;
 
-#if IS_ENABLED(CONFIG_SERVICE_QSPI)
+#if IS_ENABLED(CONFIG_SERVICE_BOOT) && IS_ENABLED(CONFIG_SERVICE_QSPI)
     assert(ppBootImage);
 
     // need to do an initial copy of the boot header into our structure, for subsequent use
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Preparing to copy from QSPI to DDR ..." CRLF);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Preparing to copy from QSPI to DDR ...\n");
 
     size_t srcLBAOffset = 0u;
     assert(pStorage);
@@ -477,18 +411,17 @@ static bool getBootImageFromQSPI_(struct HSS_Storage *pStorage, struct HSS_BootI
     uint32_t blockSize, eraseSize, blockCount;
     pStorage->getInfo(&blockSize, &eraseSize, &blockCount);
 
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Attempting to read image header (%d bytes) ..." CRLF,
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Attempting to read image header (%d bytes) ...\n",
         sizeof(struct HSS_BootImage));
     result = HSS_QSPI_ReadBlock(&bootImage, srcLBAOffset * blockSize,
         sizeof(struct HSS_BootImage));
-
     if (!result) {
-        mHSS_DEBUG_PRINTF(LOG_ERROR, "HSS_QSPI_ReadBlock() failed" CRLF);
+        mHSS_DEBUG_PRINTF(LOG_ERROR, "HSS_QSPI_ReadBlock() failed\n");
     } else {
-        result = verifyMagic_(&bootImage);
+        result = HSS_Boot_VerifyMagic(&bootImage);
 
         if (!result) {
-            mHSS_DEBUG_PRINTF(LOG_ERROR, "verifyMagic_() failed" CRLF);
+            mHSS_DEBUG_PRINTF(LOG_ERROR, "HSS_Boot_VerifyMagic() failed\n");
         } else {
             int perf_ctr_index = PERF_CTR_UNINITIALIZED;
             HSS_PerfCtr_Allocate(&perf_ctr_index, "Boot Image QSPI Copy");
@@ -501,7 +434,7 @@ static bool getBootImageFromQSPI_(struct HSS_Storage *pStorage, struct HSS_BootI
             HSS_PerfCtr_Lap(perf_ctr_index);
 
             if (!result) {
-                 mHSS_DEBUG_PRINTF(LOG_ERROR, "copyBootImageToDDR_() failed" CRLF);
+                 mHSS_DEBUG_PRINTF(LOG_ERROR, "copyBootImageToDDR_() failed\n");
             }
         }
     }
@@ -513,7 +446,7 @@ static bool getBootImageFromQSPI_(struct HSS_Storage *pStorage, struct HSS_BootI
 void HSS_BootSelectQSPI(void)
 {
 #if IS_ENABLED(CONFIG_SERVICE_QSPI)
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Selecting QSPI as boot source ..." CRLF);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Selecting QSPI as boot source ...\n");
     pDefaultStorage = &qspiStorage_;
 #else
     (void)getBootImageFromQSPI_;
@@ -525,13 +458,13 @@ static bool getBootImageFromPayload_(struct HSS_Storage *pStorage, struct HSS_Bo
     bool result = false;
     (void)pStorage;
 
-#if IS_ENABLED(CONFIG_SERVICE_BOOT_USE_PAYLOAD)
+#if IS_ENABLED(CONFIG_SERVICE_BOOT) && IS_ENABLED(CONFIG_SERVICE_BOOT_USE_PAYLOAD)
     assert(ppBootImage);
 
     extern struct HSS_BootImage _payload_start;
     *ppBootImage = (struct HSS_BootImage *)&_payload_start;
 
-    result = verifyMagic_(*ppBootImage);
+    result = HSS_Boot_VerifyMagic(*ppBootImage);
     printBootImageDetails_(*ppBootImage);
 #endif
 
@@ -541,14 +474,14 @@ static bool getBootImageFromPayload_(struct HSS_Storage *pStorage, struct HSS_Bo
 void HSS_BootSelectPayload(void)
 {
 #if IS_ENABLED(CONFIG_SERVICE_USE_PAYLOAD)
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Selecting Payload as boot source ..." CRLF);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Selecting Payload as boot source ...\n");
     pDefaultStorage = &payloadStorage_;
 #else
     (void)getBootImageFromPayload_;
 #endif
 }
 
-#if IS_ENABLED(CONFIG_SERVICE_SPI)
+#if IS_ENABLED(CONFIG_SERVICE_BOOT) && IS_ENABLED(CONFIG_SERVICE_SPI)
 static bool spiFlashReadBlock_(void *dst, size_t offs, size_t count) {
    int retval = MSS_SYS_spi_copy((uintptr_t)dst, offs, count, /* options */ 3, /* mb_offset */ 0);
 
@@ -564,14 +497,14 @@ static bool getBootImageFromSpiFlash_(struct HSS_Storage *pStorage, struct HSS_B
     bool result = false;
     (void)pStorage;
 
-#if IS_ENABLED(CONFIG_SERVICE_SPI)
+#if IS_ENABLED(CONFIG_SERVICE_BOOT) && IS_ENABLED(CONFIG_SERVICE_SPI)
 
     assert(ppBootImage);
 
     size_t srcOffset = CONFIG_SERVICE_BOOT_SPI_FLASH_OFFSET;
 
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Preparing to copy from SPI Flash +0x%lx to DDR ..." CRLF, srcOffset);
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Attempting to read image header (%d bytes) ..." CRLF,
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Preparing to copy from SPI Flash +0x%lx to DDR ...\n", srcOffset);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Attempting to read image header (%d bytes) ...\n",
         sizeof(struct HSS_BootImage));
 
     MSS_SYS_select_service_mode(MSS_SYS_SERVICE_POLLING_MODE, NULL);
@@ -581,7 +514,7 @@ static bool getBootImageFromSpiFlash_(struct HSS_Storage *pStorage, struct HSS_B
         return false;
     }
 
-    result = verifyMagic_(&bootImage);
+    result = HSS_Boot_VerifyMagic(&bootImage);
     if (!result) {
         return false;
     }
@@ -597,7 +530,7 @@ static bool getBootImageFromSpiFlash_(struct HSS_Storage *pStorage, struct HSS_B
 void HSS_BootSelectSPI(void)
 {
 #if IS_ENABLED(CONFIG_SERVICE_SPI)
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Selecting SPI Flash as boot source ..." CRLF);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Selecting SPI Flash as boot source ...\n");
     pDefaultStorage = &spiStorage_;
 #else
     (void)getBootImageFromSpiFlash_;
@@ -618,7 +551,7 @@ bool HSS_Storage_Init(void)
     assert(pStorage);
 
     if (pStorage->init) {
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "initialize %s" CRLF, pStorage->name);
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "initialize %s\n", pStorage->name);
         result = pStorage->init();
     }
 
@@ -654,7 +587,7 @@ void HSS_Storage_GetInfo(uint32_t *pBlockSize, uint32_t *pEraseSize, uint32_t *p
     if (pStorage->getInfo) {
         pStorage->getInfo(pBlockSize, pEraseSize, pBlockCount);
     }
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s - %u byte pages, %u byte blocks, %u pages" CRLF, pStorage->name, *pBlockSize, *pEraseSize, *pBlockCount);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s - %u byte pages, %u byte blocks, %u pages\n", pStorage->name, *pBlockSize, *pEraseSize, *pBlockCount);
 }
 
 void HSS_Storage_FlushWriteBuffer(void)
