@@ -28,7 +28,7 @@ HSSTicks_t CSR_GetTickCount(void)
 {
     HSSTicks_t tickCount;
 
-    tickCount = mHSS_CSR_READ(mcycle);
+    tickCount = csr_read(mcycle);
 
     return tickCount;
 }
@@ -64,7 +64,7 @@ void CSR_ClearMSIP(void)
         break;
 
     default:
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Unknown hart ID %u" CRLF, hartid);
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Unknown hart ID %u\n", hartid);
         assert(0 == 1);
         break;
     }
