@@ -23,6 +23,9 @@
 #include "hss_clock.h"
 #include "hss_debug.h"
 #include "hss_perfctr.h"
+#include "common/mss_peripherals.h"
+#include "hss_crc32.h"
+#include "u54_state.h"
 
 #include <assert.h>
 #include <string.h>
@@ -31,7 +34,11 @@
 
 #if IS_ENABLED(CONFIG_OPENSBI)
 #  include "sbi/riscv_asm.h"
+#  define ffs SBI_FFS
+#  define fls SBI_FLS
 #  include "sbi/sbi_bitops.h"
+#  undef ffs
+#  undef fls
 #  include "sbi/sbi_hart.h"
 #  include "sbi_init.h"
 #  include "sbi_scratch.h"
@@ -54,10 +61,18 @@
 #include "system_startup.h"
 #include "fpga_design_config/fpga_design_config.h"
 
+#if IS_ENABLED(CONFIG_CRYPTO_SIGNING)
+#  include "hss_boot_secure.h"
+#endif
+
+#if IS_ENABLED(CONFIG_SERVICE_OPENSBI_RPROC)
+#  include "opensbi_rproc_ecall.h"
+#endif
+
 
 /* Timeouts */
-#define BOOT_SETUP_PMP_COMPLETE_TIMEOUT (ONE_SEC * 5u)
-#define BOOT_WAIT_TIMEOUT               (ONE_SEC * 2u)
+#define BOOT_SETUP_PMP_COMPLETE_TIMEOUT (ONE_SEC * 1u)
+#define BOOT_WAIT_TIMEOUT               (ONE_SEC * 5u)
 
 #define BOOT_SUB_CHUNK_SIZE 256u
 
@@ -87,6 +102,8 @@ static void boot_do_download_chunk(struct HSS_BootChunkDesc const *pChunk,
     ptrdiff_t subChunkOffset, size_t subChunkSize);
 static void boot_do_zero_init_chunk(struct HSS_BootZIChunkDesc const *pZiChunk);
 
+static bool validateCrc_(struct HSS_BootImage *pImage);
+
 /*!
  * \brief Boot Driver States
  *
@@ -312,22 +329,22 @@ static bool check_for_ipi_acks(struct StateMachine * const pMyMachine)
 static void boot_init_handler(struct StateMachine * const pMyMachine)
 {
     if (pBootImage) {
-        //mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::\tstarting boot" CRLF, pMyMachine->pMachineName);
+        //mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::\tstarting boot\n", pMyMachine->pMachineName);
 
+        pMyMachine->startTime = HSS_GetTime();
         struct HSS_Boot_LocalData * const pInstanceData = pMyMachine->pInstanceData;
         enum HSSHartId const target = pInstanceData->target;
 
         if (pBootImage->hart[target-1].flags & BOOT_FLAG_SKIP_OPENSBI) {
-	   mHSS_DEBUG_PRINTF(LOG_STATUS, "%s:: BOOT_FLAG_SKIP_OPENSBI found" CRLF, pMyMachine->pMachineName);
+	   mHSS_DEBUG_PRINTF(LOG_STATUS, "%s:: BOOT_FLAG_SKIP_OPENSBI found\n", pMyMachine->pMachineName);
         }
 
         HSS_PerfCtr_Allocate(&pInstanceData->perfCtr, pMyMachine->pMachineName);
-
         pMyMachine->state = BOOT_SETUP_PMP;
     } else {
         // unexpected error state
         if (!pBootImage) {
-            mHSS_DEBUG_PRINTF(LOG_ERROR, "%s::\tNo Boot Image registered" CRLF, pMyMachine->pMachineName);
+            mHSS_DEBUG_PRINTF(LOG_ERROR, "%s::\tNo Boot Image registered\n", pMyMachine->pMachineName);
         }
         pMyMachine->state = BOOT_ERROR;
     }
@@ -355,7 +372,7 @@ static void boot_setup_pmp_onEntry(struct StateMachine * const pMyMachine)
             } else if ((peer == target) ||
                 (pBootImage->hart[peer-1].entryPoint == pBootImage->hart[target-1].entryPoint)) {
                 pInstanceData->hartMask |= (1u << peer);
-                //mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Registering hart %d to domain \"%s\"" CRLF,
+                //mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Registering u54_%d to domain \"%s\"\n",
                 //    pMyMachine->pMachineName, peer, pBootImage->hart[target-1].name);
                 mpfs_domains_register_hart(peer, target);
             }
@@ -366,14 +383,16 @@ static void boot_setup_pmp_onEntry(struct StateMachine * const pMyMachine)
         if (pBootImage->hart[target-1].flags & BOOT_FLAG_SKIP_OPENSBI) {
             // skipping OpenSBI => don't register as a domain
         } else {
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Registering domain \"%s\" (hart mask 0x%x)" CRLF,
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Registering domain \"%s\" (hart mask 0x%x)\n",
                 pMyMachine->pMachineName, pBootImage->hart[target-1].name, pInstanceData->hartMask);
 
             mpfs_domains_register_boot_hart(pBootImage->hart[target-1].name,
                 pInstanceData->hartMask, target,
                 pBootImage->hart[target-1].privMode,
                 (void *)pBootImage->hart[target-1].entryPoint,
-                (void *)pInstanceData->ancilliaryData);
+                (void *)pInstanceData->ancilliaryData,
+		pBootImage->hart[target-1].flags & BOOT_FLAG_ALLOW_COLD_REBOOT,
+		pBootImage->hart[target-1].flags & BOOT_FLAG_ALLOW_WARM_REBOOT);
         }
     }
 }
@@ -398,16 +417,19 @@ static void boot_setup_pmp_handler(struct StateMachine * const pMyMachine)
 
 static void boot_setup_pmp_complete_onEntry(struct StateMachine * const pMyMachine)
 {
-    //mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Checking for IPI ACKs: - -" CRLF, pMyMachine->pMachineName);
+    //mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Checking for IPI ACKs: - -\n", pMyMachine->pMachineName);
 }
 
 static void boot_setup_pmp_complete_handler(struct StateMachine * const pMyMachine)
 {
+
+    struct HSS_Boot_LocalData * const pInstanceData = pMyMachine->pInstanceData;
+    enum HSSHartId const target = pInstanceData->target;
+
     if (HSS_Timer_IsElapsed(pMyMachine->startTime, BOOT_SETUP_PMP_COMPLETE_TIMEOUT)) {
-        mHSS_DEBUG_PRINTF(LOG_ERROR, "%s::Timeout after %" PRIu64 " iterations" CRLF,
+        mHSS_DEBUG_PRINTF(LOG_ERROR, "%s::Timeout after %" PRIu64 " iterations\n",
             pMyMachine->pMachineName, pMyMachine->executionCount);
 
-        struct HSS_Boot_LocalData * const pInstanceData = pMyMachine->pInstanceData;
         for (unsigned int i = 0u; i < ARRAY_SIZE(bootMachine); i++) {
             enum HSSHartId peer = bootMachine[i].hartId;
             free_msg_index_aux(pInstanceData, peer);
@@ -420,9 +442,12 @@ static void boot_setup_pmp_complete_handler(struct StateMachine * const pMyMachi
         // need to free as received, not all at once...
 
         if (check_for_ipi_acks(pMyMachine)) {
-            //mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Checking for IPI ACKs: ACK/IDLE ACK" CRLF, pMyMachine->pMachineName);
-            //mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::PMP setup completed" CRLF, pMyMachine->pMachineName);
+            //mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Checking for IPI ACKs: ACK/IDLE ACK\n", pMyMachine->pMachineName);
+            //mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::PMP setup completed\n", pMyMachine->pMachineName);
 
+        if (pBootImage->hart[target-1].flags & BOOT_FLAG_SKIP_AUTOBOOT)
+            pMyMachine->state = BOOT_IDLE;
+        else
             pMyMachine->state = BOOT_ZERO_INIT_CHUNKS;
         }
     }
@@ -451,7 +476,7 @@ static void boot_zero_init_chunks_handler(struct StateMachine * const pMyMachine
     if (pZiChunk->size != 0u) {
         if (target == pZiChunk->owner) {
 #if IS_ENABLED(CONFIG_DEBUG_CHUNK_DOWNLOADS)
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::%d:ziChunk->0x%x, %u bytes" CRLF,
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::%d:ziChunk->0x%x, %u bytes\n",
                 pMyMachine->pMachineName, pInstanceData->ziChunkCount,
                 (uintptr_t)pZiChunk->execAddr, pZiChunk->size);
 #endif
@@ -473,17 +498,17 @@ static void boot_download_chunks_onEntry(struct StateMachine * const pMyMachine)
     assert(pBootImage != NULL);
 
     if (pBootImage->hart[target-1].numChunks) {
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Processing boot image: \"%s\"" CRLF,
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Processing boot image: \"%s\"\n",
             pMyMachine->pMachineName, pBootImage->hart[target-1].name);
         pInstanceData->pChunk =
             (struct HSS_BootChunkDesc *)((char *)pBootImage + pBootImage->chunkTableOffset);
 
 #if IS_ENABLED(CONFIG_DEBUG_CHUNK_DOWNLOADS)
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::firstChunk is %u" CRLF,
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::firstChunk is %u\n",
             pMyMachine->pMachineName, pBootImage->hart[target-1].firstChunk);
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::lastChunk is %u" CRLF,
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::lastChunk is %u\n",
             pMyMachine->pMachineName, pBootImage->hart[target-1].lastChunk);
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::numChunks is %u" CRLF,
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::numChunks is %u\n",
             pMyMachine->pMachineName, pBootImage->hart[target-1].numChunks);
 #endif
 
@@ -514,7 +539,7 @@ static void boot_download_chunks_handler(struct StateMachine * const pMyMachine)
                 && (HSS_PMP_CheckWrite(target, pChunk->execAddr, pChunk->size))) {
 #if IS_ENABLED(CONFIG_DEBUG_CHUNK_DOWNLOADS)
                 if (!pInstanceData->subChunkOffset) {
-                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::%d:chunk@0x%x->0x%x, %u bytes" CRLF,
+                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::%d:chunk@0x%x->0x%x, %u bytes\n",
                         pMyMachine->pMachineName, pInstanceData->chunkCount,
                         (uintptr_t)pChunk->loadAddr,
                         (uintptr_t)pChunk->execAddr, pChunk->size);
@@ -531,7 +556,7 @@ static void boot_download_chunks_handler(struct StateMachine * const pMyMachine)
 
                 if ((pChunk->owner & BOOT_FLAG_ANCILLIARY_DATA)
                     && (!pInstanceData->ancilliaryData)) {
-                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::%d:ancilliary data found at 0x%x" CRLF,
+                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::%d:ancilliary data found at 0x%x\n",
                         pMyMachine->pMachineName, pInstanceData->chunkCount, pChunk->execAddr);
                     pInstanceData->ancilliaryData = pChunk->execAddr;
                 }
@@ -540,7 +565,7 @@ static void boot_download_chunks_handler(struct StateMachine * const pMyMachine)
                 pInstanceData->subChunkOffset += BOOT_SUB_CHUNK_SIZE;
                 if (pInstanceData->subChunkOffset > pChunk->size) {
 #  if IS_ENABLED(CONFIG_DEBUG_CHUNK_DOWNLOADS)
-                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::%d:sub-chunk finished at 0x%x" CRLF,
+                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::%d:sub-chunk finished at 0x%x\n",
                         pMyMachine->pMachineName, pInstanceData->chunkCount, pInstanceData->subChunkOffset);
 #  endif
                     pInstanceData->subChunkOffset = 0u;
@@ -554,10 +579,10 @@ static void boot_download_chunks_handler(struct StateMachine * const pMyMachine)
             } else {
                 if (pChunk->owner == target) {
                     mHSS_DEBUG_PRINTF(LOG_ERROR,
-                        "%s::Skipping chunk %p due to invalid permissions" CRLF, pMyMachine->pMachineName, pChunk);
+                        "%s::Skipping chunk %p due to invalid permissions\n", pMyMachine->pMachineName, pChunk);
                 } else {
                     mHSS_DEBUG_PRINTF(LOG_WARN,
-                        "%s::Skipping chunk %p due to ownership %d" CRLF, pMyMachine->pMachineName, pChunk, pChunk->owner);
+                        "%s::Skipping chunk %p due to ownership %d\n", pMyMachine->pMachineName, pChunk, pChunk->owner);
                 }
 
                 pInstanceData->pChunk++;
@@ -619,7 +644,7 @@ static void boot_opensbi_init_handler(struct StateMachine * const pMyMachine)
                 assert(result);
 
                 if (pBootImage->hart[target-1].flags & BOOT_FLAG_SKIP_OPENSBI) {
-                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::u54_%u:goto %p" CRLF, pMyMachine->pMachineName,
+                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::u54_%u:goto %p\n", pMyMachine->pMachineName,
                         peer, pBootImage->hart[peer-1].entryPoint);
 
                     result = IPI_MessageDeliver(pInstanceData->msgIndexAux[peer-1], peer,
@@ -629,7 +654,7 @@ static void boot_opensbi_init_handler(struct StateMachine * const pMyMachine)
                         (void *)pInstanceData->ancilliaryData);
                     assert(result);
                 } else {
-                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::u54_%u:sbi_init %p" CRLF, pMyMachine->pMachineName,
+                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::u54_%u:sbi_init %p\n", pMyMachine->pMachineName,
                         peer, pBootImage->hart[peer-1].entryPoint);
 
                     result = IPI_MessageDeliver(pInstanceData->msgIndexAux[peer-1], peer,
@@ -639,7 +664,7 @@ static void boot_opensbi_init_handler(struct StateMachine * const pMyMachine)
                         (void *)pInstanceData->ancilliaryData);
 
                     if (!result) {
-                        mHSS_DEBUG_PRINTF(LOG_ERROR, "%s::u54_%u:sbi_init failed" CRLF,
+                        mHSS_DEBUG_PRINTF(LOG_ERROR, "%s::u54_%u:sbi_init failed\n",
                             pMyMachine->pMachineName, peer);
 
                         pMyMachine->state = BOOT_ERROR;
@@ -670,7 +695,7 @@ static void boot_opensbi_init_onExit(struct StateMachine * const pMyMachine)
         mb_i();
 
         if (pBootImage->hart[target-1].flags & BOOT_FLAG_SKIP_OPENSBI) {
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::u54_%u:goto %p" CRLF, pMyMachine->pMachineName,
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::u54_%u:goto %p\n", pMyMachine->pMachineName,
                 target, pBootImage->hart[target-1].entryPoint);
 
             result = IPI_MessageDeliver(pInstanceData->msgIndex, target,
@@ -681,7 +706,7 @@ static void boot_opensbi_init_onExit(struct StateMachine * const pMyMachine)
 
             assert(result);
         } else {
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::u54_%u:sbi_init %p" CRLF, pMyMachine->pMachineName,
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::u54_%u:sbi_init %p\n", pMyMachine->pMachineName,
                 target, pBootImage->hart[target-1].entryPoint);
 
             result = IPI_MessageDeliver(pInstanceData->msgIndex, target,
@@ -693,7 +718,7 @@ static void boot_opensbi_init_onExit(struct StateMachine * const pMyMachine)
             assert(result);
         }
     } else {
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::target is %u, pBootImage is %p, skipping goto/sbi_init %p" CRLF,
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::target is %u, pBootImage is %p, skipping goto/sbi_init %p\n",
             pMyMachine->pMachineName, target, pBootImage, pBootImage->hart[target-1].entryPoint);
     }
 }
@@ -703,7 +728,7 @@ static void boot_opensbi_init_onExit(struct StateMachine * const pMyMachine)
 static void boot_wait_onEntry(struct StateMachine * const pMyMachine)
 {
     (void)pMyMachine;
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Checking for IPI ACKs: - -" CRLF, pMyMachine->pMachineName);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Checking for IPI ACKs: - -\n", pMyMachine->pMachineName);
 }
 
 static void boot_wait_handler(struct StateMachine * const pMyMachine)
@@ -711,11 +736,14 @@ static void boot_wait_handler(struct StateMachine * const pMyMachine)
     struct HSS_Boot_LocalData * const pInstanceData = pMyMachine->pInstanceData;
     enum HSSHartId const target = pInstanceData->target;
 
+    pMyMachine->startTime = HSS_GetTime();
+
     if (!pBootImage->hart[target-1].entryPoint) {
         // nothing for me to do, not expecting GOTO ack...
+        HSS_U54_SetState_Ex(target, HSS_State_Idle);
         pMyMachine->state = BOOT_IDLE;
     } else if (HSS_Timer_IsElapsed(pMyMachine->startTime, BOOT_WAIT_TIMEOUT)) {
-        mHSS_DEBUG_PRINTF(LOG_ERROR, "%s::Timeout after %" PRIu64 " iterations" CRLF,
+        mHSS_DEBUG_PRINTF(LOG_ERROR, "%s::Timeout after %" PRIu64 " iterations\n",
             pMyMachine->pMachineName, pMyMachine->executionCount);
 
         for (unsigned int i = 0u; i < ARRAY_SIZE(bootMachine); i++) {
@@ -735,7 +763,7 @@ static void boot_wait_handler(struct StateMachine * const pMyMachine)
             mHSS_ReadModWriteRegU32(SYSREGSCB, MSS_STATUS, 0xFFFFu, 1u << (target-1));
 #endif
 
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Checking for IPI ACKs: ACK/IDLE ACK" CRLF,
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%s::Checking for IPI ACKs: ACK/IDLE ACK\n",
                 pMyMachine->pMachineName);
             pMyMachine->state = BOOT_IDLE;
         }
@@ -746,10 +774,10 @@ static void boot_wait_handler(struct StateMachine * const pMyMachine)
 
 static void boot_error_handler(struct StateMachine * const pMyMachine)
 {
-    mHSS_DEBUG_PRINTF(LOG_ERROR, "%s::" CRLF
-        "*******************************************************************" CRLF
-        "* WARNING: Boot Error - transitioning to IDLE                     *" CRLF
-        "*******************************************************************" CRLF,
+    mHSS_DEBUG_PRINTF(LOG_ERROR, "%s::\n"
+        "*******************************************************************\n"
+        "* WARNING: Boot Error - transitioning to IDLE                     *\n"
+        "*******************************************************************\n",
         pMyMachine->pMachineName);
 
     pMyMachine->state = BOOT_IDLE;
@@ -784,10 +812,13 @@ bool HSS_Boot_Harts(const union HSSHartBitmask restartHartBitmask)
     // TODO: should it restart all, or only the non-busy boot state machines??
     //
     for (unsigned int i = 0u; i < ARRAY_SIZE(bootMachine); i++) {
-        if (restartHartBitmask.uint && (1u << bootMachine[i].hartId)) {
+        if (restartHartBitmask.uint & (1u << bootMachine[i].hartId)) {
             struct StateMachine * const pMachine = bootMachine[i].pMachine;
 
-            if (pMachine->state == BOOT_SETUP_PMP_COMPLETE) {
+            if (pMachine->state == BOOT_OPENSBI_INIT) {
+                pMachine->state = (stateType_t)BOOT_OPENSBI_INIT;
+                result = true;
+            } else if (pMachine->state == BOOT_SETUP_PMP_COMPLETE) {
                pMachine->state = (stateType_t)BOOT_INITIALIZATION;
                result = true;
             } else if ((pMachine->state == BOOT_INITIALIZATION) || (pMachine->state == BOOT_IDLE)) {
@@ -795,7 +826,7 @@ bool HSS_Boot_Harts(const union HSSHartBitmask restartHartBitmask)
                result = true;
             } else {
                result = false;
-               mHSS_DEBUG_PRINTF(LOG_ERROR, "invalid hart state %d for hart %u" CRLF, pMachine->state, i+1u);
+               mHSS_DEBUG_PRINTF(LOG_ERROR, "invalid hart state %d for u54_%u\n", pMachine->state, i+1u);
             }
         }
     }
@@ -807,8 +838,10 @@ enum IPIStatusCode HSS_Boot_RestartCore(enum HSSHartId source)
 {
     enum IPIStatusCode result = IPI_FAIL;
 
-    if (source != HSS_HART_ALL) {
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "called for hart %u" CRLF, source);
+    if (!HSS_Boot_ValidateImage(pBootImage)) {
+        mHSS_DEBUG_PRINTF(LOG_ERROR, "validation failed for u54_%u\n", source);
+    } else if (source != HSS_HART_ALL) {
+        //mHSS_DEBUG_PRINTF(LOG_NORMAL, "called for u54_%u\n", source);
 
         union HSSHartBitmask restartHartBitmask = { .uint = 0u };
 
@@ -833,7 +866,7 @@ enum IPIStatusCode HSS_Boot_RestartCore(enum HSSHartId source)
             }
         }
     } else {
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "called for all harts" CRLF);
+        //mHSS_DEBUG_PRINTF(LOG_NORMAL, "called for all harts\n");
 
         const union HSSHartBitmask restartHartBitmask = {
             .s = {
@@ -853,6 +886,18 @@ enum IPIStatusCode HSS_Boot_RestartCore(enum HSSHartId source)
     return result;
 }
 
+bool HSS_SkipBoot_IsSet(enum HSSHartId target)
+{
+    bool result = false;
+
+    assert(pBootImage != NULL);
+
+    if (pBootImage->hart[target-1].flags & BOOT_FLAG_SKIP_AUTOBOOT)
+        result = true;
+
+    return result;
+}
+
 enum IPIStatusCode HSS_Boot_IPIHandler(TxId_t transaction_id, enum HSSHartId source,
     uint32_t immediate_arg, void *p_extended_buffer_in_ddr, void *p_ancilliary_buffer_in_ddr)
 {
@@ -863,12 +908,117 @@ enum IPIStatusCode HSS_Boot_IPIHandler(TxId_t transaction_id, enum HSSHartId sou
     (void)p_ancilliary_buffer_in_ddr;
 
     // boot strap IPI received from one of the U54s...
-    //mHSS_DEBUG_PRINTF(LOG_ERROR, "called for %d" CRLF, source);
+    //mHSS_DEBUG_PRINTF(LOG_ERROR, "called for %d\n", source);
+
+    /* Remoteproc use case 1.1:
+       Elf file loaded by Linux using rproc elf loader, so
+       no need to reload the payload on the HSS
+    */
+#if IS_ENABLED(CONFIG_SERVICE_OPENSBI_RPROC)
+    if(immediate_arg == RPROC_BOOT)
+    {
+        struct RemoteProcMsg *rproc_data = (struct RemoteProcMsg *)p_extended_buffer_in_ddr;
+        source = rproc_data->target;
+        struct StateMachine * const pMachine = bootMachine[source - 1].pMachine;
+        pMachine->state = (stateType_t)BOOT_OPENSBI_INIT;
+    }
+#endif
 
     return HSS_Boot_RestartCore(source);
     return IPI_SUCCESS;
 }
 
+
+static bool validateCrc_(struct HSS_BootImage *pImageHdr)
+{
+    bool result = false;
+    uint32_t headerCrc;
+
+    struct HSS_BootImage shadowHdr = *pImageHdr;
+
+    shadowHdr.headerCrc = 0u;
+    memset(&(shadowHdr.signature), 0, sizeof(shadowHdr.signature));
+
+    size_t crcLen;
+    switch (pImageHdr->version) {
+    case 0u:
+        // pre crypto-signing, the BootImage format was slightly different, so to ensure
+        // no CRC failures on older images, we use a legacy structure size...
+        crcLen = sizeof(struct HSS_BootImage_v0);
+        break;
+
+    default:
+        crcLen = sizeof(struct HSS_BootImage);
+        break;
+    }
+
+    headerCrc = CRC32_calculate((const uint8_t *)&shadowHdr, crcLen);
+    if (headerCrc == pImageHdr->headerCrc) {
+        result = true;
+    } else {
+        mHSS_DEBUG_PRINTF(LOG_ERROR, "Checked HSS_BootImage header CRC (%p->%p): calculated %08x vs expected %08x\n",
+            pImageHdr, (char *)pImageHdr + sizeof(struct HSS_BootImage), headerCrc, pImageHdr->headerCrc);
+    }
+
+    return result;
+}
+
+bool HSS_Boot_ValidateImage(struct HSS_BootImage *pImage)
+{
+    bool result = false;
+
+#if IS_ENABLED(CONFIG_SERVICE_BOOT)
+    //
+    // now have a Full Boot Image, let's check it is a valid one...
+    //
+    {
+        if (!pImage) {
+            mHSS_DEBUG_PRINTF(LOG_ERROR, "Boot Image NULL, ignoring\n");
+        } else if (pImage->magic != mHSS_BOOT_MAGIC) {
+            mHSS_DEBUG_PRINTF(LOG_ERROR, "Boot Image magic invalid, ignoring\n");
+#  if IS_ENABLED(CONFIG_CRYPTO_SIGNING)
+        } else if (!HSS_Boot_Secure_CheckCodeSigning(pImage)) {
+            mHSS_DEBUG_PRINTF(LOG_ERROR, "Boot Image failed code signing\n");
+#  endif
+        } else if (validateCrc_(pImage)) {
+            mHSS_DEBUG_PRINTF(LOG_STATUS, "Boot image passed CRC\n");
+
+        // GCC 9.x appears to dislike the pImage cast, and sees dereferencing the
+        // set name as an out-of-bounds... So we'll disable that warning just for
+        // this print...
+#  pragma GCC diagnostic push
+#  pragma GCC diagnostic ignored "-Warray-bounds"
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "Boot image set name: \"%s\"\n", pImage->set_name);
+#  pragma GCC diagnostic pop
+
+#  if defined(CONFIG_SERVICE_BOOT_CUSTOM_FLOW)
+            result = HSS_Boot_Custom();
+#  else
+            result = true;
+#  endif
+        } else {
+            mHSS_DEBUG_PRINTF(LOG_ERROR, "Boot image failed CRC\n");
+        }
+    }
+#endif
+
+    return result;
+}
+
+bool HSS_Boot_VerifyMagic(struct HSS_BootImage const * const pImage)
+{
+    bool result = false;
+
+    if ((pImage->magic == mHSS_BOOT_MAGIC) || (pImage->magic == mHSS_COMPRESSED_MAGIC)) {
+        result = true;
+    } else {
+        mHSS_DEBUG_PRINTF(LOG_WARN, "magic is %08x vs expected %08x or %08x\n",
+            pImage->magic, mHSS_BOOT_MAGIC, mHSS_COMPRESSED_MAGIC);
+    }
+
+    return result;
+}
+
 void HSS_Register_Boot_Image(struct HSS_BootImage *pImage)
 {
     pBootImage = pImage;
@@ -897,16 +1047,16 @@ bool HSS_Boot_Custom(void)
     }
 
     if (!numChunks || !target) {
-        mHSS_DEBUG_PRINTF(LOG_ERROR, "Failed to find target HART" CRLF);
+        mHSS_DEBUG_PRINTF(LOG_ERROR, "Failed to find target HART\n");
         return false;
     }
 
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Zeroing chunks for HART%d" CRLF, target);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Zeroing chunks for HART%d\n", target);
     pZiChunk = (struct HSS_BootZIChunkDesc const *)((char *)pBootImage + pBootImage->ziChunkTableOffset);
     while (pZiChunk->size != 0u) {
         if (target == pZiChunk->owner) {
 #if IS_ENABLED(CONFIG_DEBUG_CHUNK_DOWNLOADS)
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%d:ziChunk->0x%x, %u bytes" CRLF,
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "%d:ziChunk->0x%x, %u bytes\n",
                 chunkNum, (uintptr_t)pZiChunk->execAddr, pZiChunk->size);
 #endif
             boot_do_zero_init_chunk(pZiChunk);
@@ -918,12 +1068,12 @@ bool HSS_Boot_Custom(void)
     pChunk = (struct HSS_BootChunkDesc *)((char *)pBootImage + pBootImage->chunkTableOffset);
     chunkNum = 0u;
     pChunk += firstChunk;
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Downloading chunks for HART%d at 0x%x" CRLF, target, (uintptr_t)pChunk->execAddr);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Downloading chunks for HART%d at 0x%x\n", target, (uintptr_t)pChunk->execAddr);
     while (pChunk->size != 0u) {
         if ((pChunk->owner == target) && (HSS_PMP_CheckWrite(target, pChunk->execAddr, pChunk->size))) {
 #if IS_ENABLED(CONFIG_DEBUG_CHUNK_DOWNLOADS)
            if (!subChunkOffset) {
-                mHSS_DEBUG_PRINTF(LOG_NORMAL, "%d:chunk@0x%x->0x%x, %u bytes" CRLF,
+                mHSS_DEBUG_PRINTF(LOG_NORMAL, "%d:chunk@0x%x->0x%x, %u bytes\n",
                         chunkNum, (uintptr_t)pChunk->loadAddr,
                         (uintptr_t)pChunk->execAddr, pChunk->size);
             }
@@ -955,7 +1105,7 @@ bool HSS_Boot_Custom(void)
     uintptr_t custom_entryPoint = pBootImage->hart[target - 1].entryPoint;
     uint8_t custom_privMode = PRV_M;
 
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "All HARTs jumping to entry address 0x%lx in M-mode" CRLF, custom_entryPoint);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "All HARTs jumping to entry address 0x%lx in M-mode\n", custom_entryPoint);
     for (i = 1; i < MAX_NUM_HARTS; i++) {
         IPI_Send(i, IPI_MSG_OPENSBI_INIT, 0, custom_privMode, (void * const)custom_entryPoint, NULL);
     }
@@ -984,8 +1134,9 @@ enum IPIStatusCode HSS_Boot_PMPSetupHandler(TxId_t transaction_id, enum HSSHartI
 
     // request to setup PMP by E51 received
     enum HSSHartId myHartId = current_hartid();
+    HSS_U54_SetState(HSS_State_Booting);
 
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Hart%u ", myHartId);
+    //mHSS_DEBUG_PRINTF(LOG_NORMAL, "Hart%u ", myHartId);
 
     if (!pmpSetupFlag[myHartId]) {
         pmpSetupFlag[myHartId] = true; // PMPs can be setup only once without reboot....
@@ -1007,10 +1158,10 @@ enum IPIStatusCode HSS_Boot_PMPSetupHandler(TxId_t transaction_id, enum HSSHartI
 	(void)mss_set_apb_bus_cr((uint32_t)LIBERO_SETTING_APBBUS_CR);
         //
 
-        mHSS_DEBUG_PRINTF_EX("setup complete" CRLF);
+        //mHSS_DEBUG_PRINTF_EX("setup complete\n");
         result =  IPI_SUCCESS;
     } else {
-        mHSS_DEBUG_PRINTF_EX("PMPs already configured" CRLF);
+        //mHSS_DEBUG_PRINTF_EX("PMPs already configured\n");
         result =  IPI_SUCCESS;
     }
 
@@ -1030,8 +1181,6 @@ bool HSS_Boot_PMPSetupRequest(enum HSSHartId target, uint32_t *indexOut)
 
     assert(target != HSS_HART_ALL); // need to setup PMPs on each Hart individually
 
-    //mHSS_DEBUG_PRINTF(LOG_NORMAL, "called for hart %u" CRLF, target);
-
     result = IPI_MessageAlloc(indexOut);
     assert(result);
 
@@ -1040,7 +1189,7 @@ bool HSS_Boot_PMPSetupRequest(enum HSSHartId target, uint32_t *indexOut)
 
         // couldn't send message, so free up resources...
         if (!result) {
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "hart %u: failed to send message, so freeing" CRLF, target);
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "u54_%u: failed to send message, so freeing\n", target);
             IPI_MessageFree(*indexOut);
         }
     }
@@ -1061,7 +1210,7 @@ bool HSS_Boot_SBISetupRequest(enum HSSHartId target, uint32_t *indexOut)
 
     assert(target != HSS_HART_ALL); // need to setup SBIs on each Hart individually
 
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "called for hart %u" CRLF, target);
+    //mHSS_DEBUG_PRINTF(LOG_NORMAL, "called for u54_%u\n", target);
 
     result = IPI_MessageAlloc(indexOut);
     assert(result);
@@ -1071,7 +1220,7 @@ bool HSS_Boot_SBISetupRequest(enum HSSHartId target, uint32_t *indexOut)
 
         // couldn't send message, so free up resources...
         if (!result) {
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "hart %u: failed to send message, so freeing" CRLF, target); //TODO
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "u54_%u: failed to send message, so freeing\n", target); //TODO
             IPI_MessageFree(*indexOut);
         }
     }
