@@ -38,6 +38,7 @@
 #include "csr_helper.h"
 #include "wdog_service.h"
 #include "hss_perfctr.h"
+#include "u54_state.h"
 
 #include "hss_registry.h"
 #include "assert.h"
@@ -58,6 +59,10 @@
 #    include "beu_service.h"
 #endif
 
+#if IS_ENABLED(CONFIG_CRYPTO_SIGNING)
+#    include "hss_boot_secure.h"
+#endif
+
 #define mMAX_NUM_TOKENS 40
 static size_t argc_tokenCount = 0u;
 static char *argv_tokenArray[mMAX_NUM_TOKENS];
@@ -88,19 +93,13 @@ enum CmdId {
 #if IS_ENABLED(CONFIG_MEMTEST)
     CMD_MEMTEST,
 #endif
-#if IS_ENABLED(CONFIG_SERVICE_QSPI) //&& (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_PAYLOAD) || IS_ENABLED(CONFIG_SERVICE_SPI))
     CMD_QSPI,
-#endif
-#if IS_ENABLED(CONFIG_SERVICE_MMC) && (IS_ENABLED(CONFIG_SERVICE_QSPI) || IS_ENABLED(CONFIG_SERVICE_PAYLOAD) || IS_ENABLED(CONFIG_SERVICE_SPI))
     CMD_EMMC,
     CMD_MMC,
-#endif
 #if IS_ENABLED(CONFIG_SERVICE_PAYLOAD) && (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_QSPI) || IS_ENABLED(CONFIG_SERVICE_SPI))
     CMD_PAYLOAD,
 #endif
-#if IS_ENABLED(CONFIG_SERVICE_SPI) && (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_QSPI) || IS_ENABLED(CONFIG_SERVICE_PAYLOAD))
     CMD_SPI,
-#endif
 #if IS_ENABLED(CONFIG_SERVICE_USBDMSC) && (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_QSPI))
     CMD_USBDMSC,
 #endif
@@ -130,19 +129,16 @@ const struct tinycli_key cmdKeys[] = {
 #if IS_ENABLED(CONFIG_MEMTEST)
     { CMD_MEMTEST, "MEMTEST", "Full DDR memory test." },
 #endif
-#if IS_ENABLED(CONFIG_SERVICE_QSPI) //&& (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_PAYLOAD))
     { CMD_QSPI,    "QSPI",    "Select boot via QSPI." },
-#endif
-#if IS_ENABLED(CONFIG_SERVICE_MMC) && (IS_ENABLED(CONFIG_SERVICE_QSPI) || IS_ENABLED(CONFIG_SERVICE_PAYLOAD))
     { CMD_EMMC,    "EMMC",    "Select boot via MMC." },
     { CMD_MMC,     "MMC",     "Select boot via MMC." },
-#endif
 #if IS_ENABLED(CONFIG_SERVICE_PAYLOAD) && (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_QSPI))
     { CMD_PAYLOAD, "PAYLOAD", "Select boot via payload." },
 #endif
 #if IS_ENABLED(CONFIG_SERVICE_USBDMSC) && (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_QSPI))
     { CMD_USBDMSC, "USBDMSC", "Export eMMC as USBD Mass Storage Class." },
 #endif
+    { CMD_SPI,     "SPI",     "Select boot via SPI." },
 #if IS_ENABLED(CONFIG_SERVICE_SCRUB)
     { CMD_SCRUB, "SCRUB", "Dump Scrub service stats." },
 #endif
@@ -157,7 +153,7 @@ static void tinyCLI_PrintUptime_(void);
 static void tinyCLI_PrintHelp_(void);
 static void tinyCLI_Debug_(void);
 static void tinyCLI_Reset_(void);
-#if IS_ENABLED(CONFIG_SERVICE_MMC)
+#if IS_ENABLED(CONFIG_SERVICE_MMC) && IS_ENABLED(CONFIG_SERVICE_BOOT)
 static void tinyCLI_Boot_List_(void);
 static void tinyCLI_Boot_Select_(void);
 #endif
@@ -196,19 +192,13 @@ static struct tinycli_command commands[] = {
 #if IS_ENABLED(CONFIG_MEMTEST)
     { CMD_MEMTEST, true,  tinyCLI_CmdHandler_ },
 #endif
-#if IS_ENABLED(CONFIG_SERVICE_QSPI) //&& (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_PAYLOAD) || IS_ENABLED(CONFIG_SERVICE_SPI))
     { CMD_QSPI,    true,  tinyCLI_CmdHandler_ },
-#endif
-#if IS_ENABLED(CONFIG_SERVICE_MMC) && (IS_ENABLED(CONFIG_SERVICE_QSPI) || IS_ENABLED(CONFIG_SERVICE_PAYLOAD) || IS_ENABLED(CONFIG_SERVICE_SPI))
     { CMD_EMMC,    true,  tinyCLI_CmdHandler_ },
     { CMD_MMC,     true,  tinyCLI_CmdHandler_ },
-#endif
 #if IS_ENABLED(CONFIG_SERVICE_PAYLOAD) && (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_QSPI) || IS_ENABLED(CONFIG_SERVICE_SPI))
     { CMD_PAYLOAD, true,  tinyCLI_CmdHandler_ },
 #endif
-#if IS_ENABLED(CONFIG_SERVICE_SPI) && (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_QSPI) || IS_ENABLED(CONFIG_SERVICE_PAYLOAD))
     { CMD_SPI,     true,  tinyCLI_CmdHandler_ },
-#endif
 #if IS_ENABLED(CONFIG_SERVICE_USBDMSC) && (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_QSPI))
     { CMD_USBDMSC, true,  tinyCLI_CmdHandler_ },
 #endif
@@ -341,9 +331,9 @@ static void tinyCLI_MemTest_(void)
     }
 
     if (!status) {
-        mHSS_FANCY_PRINTF(LOG_ERROR, "Failed!" CRLF);
+        mHSS_FANCY_PRINTF(LOG_ERROR, "Failed!\n");
     } else {
-        mHSS_FANCY_PRINTF(LOG_STATUS, "Passed!" CRLF);
+        mHSS_FANCY_PRINTF(LOG_STATUS, "Passed!\n");
     }
 }
 #endif
@@ -355,11 +345,11 @@ static void tinyCLI_PrintHelp_(void)
             size_t index;
 
             if (tinyCLI_NameToKeyIndex_(cmdKeys, ARRAY_SIZE(cmdKeys), argv_tokenArray[i], &index)) {
-                mHSS_FANCY_PRINTF(LOG_NORMAL, "%s: %s" CRLF, cmdKeys[index].name, cmdKeys[index].helpString);
+                mHSS_FANCY_PRINTF(LOG_NORMAL, "%s: %s\n", cmdKeys[index].name, cmdKeys[index].helpString);
             }
         }
     } else {
-        mHSS_PUTS("Supported Commands:" CRLF "\t");
+        mHSS_PUTS("Supported Commands:\n\t");
 
         for (size_t i = 0u; i < ARRAY_SIZE(cmdKeys); i++) {
             size_t index = CMD_INVALID;
@@ -374,18 +364,14 @@ static void tinyCLI_PrintHelp_(void)
             }
             mHSS_PUTC(' ');
         }
-        mHSS_PUTS("" CRLF);
+        mHSS_PUTS("\n");
     }
 }
 
 static void tinyCLI_Reset_(void)
 {
 #if IS_ENABLED(CONFIG_SERVICE_WDOG)
-    HSS_Wdog_Reboot(HSS_HART_E51);
-    HSS_Wdog_Reboot(HSS_HART_U54_1);
-    HSS_Wdog_Reboot(HSS_HART_U54_2);
-    HSS_Wdog_Reboot(HSS_HART_U54_3);
-    HSS_Wdog_Reboot(HSS_HART_U54_4);
+    HSS_Wdog_Reboot(HSS_HART_ALL);
 #endif
 }
 
@@ -394,6 +380,14 @@ static void tinyCLI_Seg_(void)
     (void)HSS_DDRPrintSegConfig();
 }
 
+static void tinyCLI_OpenSBI_(void)
+{
+    extern void sbi_domain_dump_all(char const * const suffix);
+    sbi_domain_dump_all("      ");
+
+    HSS_U54_DumpStates();
+}
+
 static void tinyCLI_L2Cache_(void)
 {
     (void)HSS_DDRPrintL2CacheWaysConfig();
@@ -428,6 +422,7 @@ static void tinyCLI_Debug_(void)
 #if IS_ENABLED(CONFIG_SERVICE_TINYCLI_MONITOR)
         DBG_MONITOR,
 #endif
+        DBG_OPENSBI,
         DBG_SEG,
         DBG_L2CACHE,
 #if IS_ENABLED(CONFIG_DEBUG_PERF_CTRS)
@@ -447,6 +442,7 @@ static void tinyCLI_Debug_(void)
 #if IS_ENABLED(CONFIG_SERVICE_TINYCLI_MONITOR)
         { DBG_MONITOR,  "MONITOR", "monitor memory locations periodically" },
 #endif
+        { DBG_OPENSBI,  "OPENSBI", "debug OpenSBI state" },
         { DBG_SEG,      "SEG",     "display seg registers" },
         { DBG_L2CACHE,  "L2CACHE", "display l2cache settings" },
 #if IS_ENABLED(CONFIG_DEBUG_PERF_CTRS)
@@ -483,6 +479,10 @@ static void tinyCLI_Debug_(void)
             break;
 #endif
 
+        case DBG_OPENSBI:
+	    tinyCLI_OpenSBI_();
+            break;
+
         case DBG_HEXDUMP:
             tinyCLI_HexDump_();
             break;
@@ -516,17 +516,35 @@ static void tinyCLI_Debug_(void)
     }
 
     if (usageError) {
-        mHSS_PUTS("Supported options:" CRLF);
+        mHSS_PUTS("Supported options:\n");
 
         for (size_t i = 0u; i < ARRAY_SIZE(debugKeys); i++) {
-            mHSS_PRINTF("\t%s - %s" CRLF, debugKeys[i].name, debugKeys[i].helpString);
+            mHSS_PRINTF("\t%s - %s\n", debugKeys[i].name, debugKeys[i].helpString);
         }
     }
 }
 
-#if IS_ENABLED(CONFIG_SERVICE_MMC)
+#if IS_ENABLED(CONFIG_SERVICE_MMC) && IS_ENABLED(CONFIG_SERVICE_BOOT)
 extern struct HSS_Storage *HSS_BootGetActiveStorage(void);
+#endif
 
+extern struct HSS_BootImage *pBootImage;
+static void tinyCLI_Boot_Info_(void)
+{
+    if ((pBootImage->magic == mHSS_BOOT_MAGIC) || (pBootImage->magic == mHSS_COMPRESSED_MAGIC)) {
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Set Name: %s\n", pBootImage->set_name);
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Length:   %" PRIu64 " bytes\n", pBootImage->bootImageLength);
+
+#if IS_ENABLED(CONFIG_CRYPTO_SIGNING)
+        mHSS_DEBUG_PRINTF(LOG_ERROR, "Boot Image %s code signing\n",
+            HSS_Boot_Secure_CheckCodeSigning(pBootImage) ? "passed" : "failed");
+#endif
+    } else {
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Valid boot image not registered\n");
+    }
+}
+
+#if IS_ENABLED(CONFIG_SERVICE_MMC)
 static void tinyCLI_Boot_List_(void)
 {
     HSS_GPT_t gpt;
@@ -549,29 +567,29 @@ static void tinyCLI_Boot_List_(void)
             result = GPT_FindBootSectorIndex(&gpt, &srcIndex, &pGptPartitionEntry);
 
             do {
-                mHSS_DEBUG_PRINTF(LOG_NORMAL, "Boot Partition found at index %lu" CRLF, srcIndex);
+                mHSS_DEBUG_PRINTF(LOG_NORMAL, "Boot Partition found at index %lu\n", srcIndex);
 
                 if (!result) {
-                    mHSS_DEBUG_PRINTF(LOG_ERROR, "GPT_FindBootSectorIndex() failed" CRLF);
+                    mHSS_DEBUG_PRINTF(LOG_ERROR, "GPT_FindBootSectorIndex() failed\n");
                 } else {
                     struct HSS_BootImage localBootImage;
                     size_t srcLBAOffset;
 
                     result = GPT_PartitionIdToLBAOffset(&gpt, srcIndex, &srcLBAOffset);
                     if (!result) {
-                        //mHSS_DEBUG_PRINTF(LOG_ERROR, "GPT_PartitionIdToLBAOffset() failed" CRLF);
+                        //mHSS_DEBUG_PRINTF(LOG_ERROR, "GPT_PartitionIdToLBAOffset() failed\n");
                     } else {
                         result = HSS_MMC_ReadBlock(&localBootImage, srcLBAOffset * gpt.lbaSize,
                             sizeof(struct HSS_BootImage));
                     }
                     if (!result) {
-                        //mHSS_DEBUG_PRINTF(LOG_ERROR, "HSS_MMC_ReadBlock() failed" CRLF);
+                        //mHSS_DEBUG_PRINTF(LOG_ERROR, "HSS_MMC_ReadBlock() failed\n");
                     } else {
                         if ((localBootImage.magic == mHSS_BOOT_MAGIC)
                             || (localBootImage.magic == mHSS_COMPRESSED_MAGIC)) {
-                            mHSS_DEBUG_PRINTF(LOG_NORMAL, ">>%s<<" CRLF, localBootImage.set_name);
+                            mHSS_DEBUG_PRINTF(LOG_NORMAL, ">>%s<<\n", localBootImage.set_name);
                         } else {
-                            //mHSS_DEBUG_PRINTF(LOG_ERROR, "magic failed" CRLF);
+                            //mHSS_DEBUG_PRINTF(LOG_ERROR, "magic failed\n");
                         }
                     }
                 }
@@ -591,9 +609,9 @@ static void tinyCLI_Boot_Select_(void)
         size_t index = tinyCLI_strtoul_wrapper_(argv_tokenArray[2]);
         GPT_SetBootPartitionIndex(&gpt, index);
     } else {
-        mHSS_PUTS("Usage:" CRLF
-            "\tboot select <partition_index>" CRLF
-            CRLF);
+        mHSS_PUTS("Usage:\n"
+            "\tboot select <partition_index>\n"
+            "\n");
     }
 }
 #endif
@@ -603,10 +621,12 @@ static bool tinyCLI_Boot_(void)
     bool result = false;
     bool usageError = false;
     enum BootKey {
+        BOOT_INFO,
         BOOT_LIST,
         BOOT_SELECT
     };
     const struct tinycli_key bootKeys[] = {
+        { BOOT_INFO,   "INFO",     "display info about currently registered boot image" },
         { BOOT_LIST,   "LIST",     "list boot partitions" },
         { BOOT_SELECT, "SELECT",   "select active boot partition" },
     };
@@ -615,6 +635,9 @@ static bool tinyCLI_Boot_(void)
     if (argc_tokenCount > 1u) {
         if (tinyCLI_NameToKeyIndex_(bootKeys, ARRAY_SIZE(bootKeys), argv_tokenArray[1], &keyIndex)) {
             switch (keyIndex) {
+            case BOOT_INFO:
+                tinyCLI_Boot_Info_();
+                break;
 #if IS_ENABLED(CONFIG_SERVICE_MMC)
             case BOOT_LIST:
                 tinyCLI_Boot_List_();
@@ -637,10 +660,10 @@ static bool tinyCLI_Boot_(void)
     }
 
     if (usageError) {
-        mHSS_PUTS("Supported options:" CRLF);
+        mHSS_PUTS("Supported options:\n");
 
         for (size_t i = 0u; i < ARRAY_SIZE(bootKeys); i++) {
-            mHSS_PRINTF("\t%s - %s" CRLF, bootKeys[i].name, bootKeys[i].helpString);
+            mHSS_PRINTF("\t%s - %s\n", bootKeys[i].name, bootKeys[i].helpString);
         }
     }
 
@@ -655,7 +678,7 @@ static bool tinyCLI_QSPI_Erase_(void)
 {
     bool result = false;
 
-    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Erasing QSPI Flash" CRLF);
+    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Erasing QSPI Flash\n");
     HSS_QSPIInit();
     HSS_QSPI_FlashChipErase();
 
@@ -710,10 +733,10 @@ static bool tinyCLI_QSPI_(void)
     }
 
     if (usageError) {
-        mHSS_PUTS("Supported options:" CRLF);
+        mHSS_PUTS("Supported options:\n");
 
         for (size_t i = 0u; i < ARRAY_SIZE(qspiKeys); i++) {
-            mHSS_PRINTF("\t%s - %s" CRLF, qspiKeys[i].name, qspiKeys[i].helpString);
+            mHSS_PRINTF("\t%s - %s\n", qspiKeys[i].name, qspiKeys[i].helpString);
         }
     }
 
@@ -760,9 +783,9 @@ static void tinyCLI_Monitor_(void)
                     monitors[index].interval_sec = tinyCLI_strtoul_wrapper_(argv_tokenArray[3]);
                     monitors[index].startAddr = tinyCLI_strtoul_wrapper_(argv_tokenArray[4]);
                     monitors[index].count = tinyCLI_strtoul_wrapper_(argv_tokenArray[5]);
-                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Allocated monitor index %lu" CRLF, index);
+                    mHSS_DEBUG_PRINTF(LOG_NORMAL, "Allocated monitor index %lu\n", index);
                 } else {
-                    mHSS_DEBUG_PRINTF(LOG_ERROR, "All monitors are allocated" CRLF);
+                    mHSS_DEBUG_PRINTF(LOG_ERROR, "All monitors are allocated\n");
                 }
             } else {
                 usageError = true;
@@ -780,9 +803,9 @@ static void tinyCLI_Monitor_(void)
                         monitors[index].interval_sec = 0u;
                         monitors[index].startAddr = 0u;
                         monitors[index].count = 0u;
-                        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Destroyed monitor index %lu" CRLF, index);
+                        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Destroyed monitor index %lu\n", index);
                     } else {
-                        mHSS_DEBUG_PRINTF(LOG_ERROR, "Monitor index %lu not allocated" CRLF, index);
+                        mHSS_DEBUG_PRINTF(LOG_ERROR, "Monitor index %lu not allocated\n", index);
                     }
                 } else {
                     usageError = true;
@@ -800,9 +823,9 @@ static void tinyCLI_Monitor_(void)
                     if (monitors[index].allocated) {
                         monitors[index].active = monitors[index].allocated;
                         monitors[index].time = HSS_GetTime();
-                        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Enabled monitor index %lu" CRLF, index);
+                        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Enabled monitor index %lu\n", index);
                     } else {
-                        mHSS_DEBUG_PRINTF(LOG_ERROR, "Monitor index %lu not allocated" CRLF, index);
+                        mHSS_DEBUG_PRINTF(LOG_ERROR, "Monitor index %lu not allocated\n", index);
                     }
                 } else {
                     usageError = true;
@@ -819,9 +842,9 @@ static void tinyCLI_Monitor_(void)
                 if (index < ARRAY_SIZE(monitors)) {
                     if (monitors[index].allocated) {
                         monitors[index].active = false;
-                        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Disabled monitor index %lu" CRLF, index);
+                        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Disabled monitor index %lu\n", index);
                     } else {
-                        mHSS_DEBUG_PRINTF(LOG_ERROR, "Monitor index %lu not allocated" CRLF, index);
+                        mHSS_DEBUG_PRINTF(LOG_ERROR, "Monitor index %lu not allocated\n", index);
                     }
                 } else {
                     usageError = true;
@@ -832,11 +855,11 @@ static void tinyCLI_Monitor_(void)
             break;
 
         case MONITOR_LIST:
-            mHSS_PUTS(" Index Active Allocated Interval       Start_Addr    Count" CRLF
-                      "===========================================================" CRLF);
+            mHSS_PUTS(" Index Active Allocated Interval       Start_Addr    Count\n"
+                      "===========================================================\n");
 
             for (size_t index = 0; index < ARRAY_SIZE(monitors);  ++index) {
-                mHSS_PRINTF(" % 5lu % 6d % 9d % 8lu %16x %8x" CRLF,
+                mHSS_PRINTF(" % 5lu % 6d % 9d % 8lu %16x %8x\n",
                     index,
                     monitors[index].active,
                     monitors[index].allocated,
@@ -855,10 +878,10 @@ static void tinyCLI_Monitor_(void)
     }
 
     if (usageError) {
-        mHSS_PUTS("Usage:" CRLF);
+        mHSS_PUTS("Usage:\n");
 
         for (size_t i = 0u; i < ARRAY_SIZE(monitorKeys); i++) {
-            mHSS_PRINTF("\tDEBUG MONITOR %s - %s" CRLF,
+            mHSS_PRINTF("\tDEBUG MONITOR %s - %s\n",
                 monitorKeys[i].name, monitorKeys[i].helpString);
         }
     }
@@ -876,11 +899,11 @@ static void tinyCLI_CRC32_(void)
         }
 
         uint32_t result = CRC32_calculate((const uint8_t *)startAddr, count);
-        mHSS_PRINTF("CRC32: 0x%x" CRLF, result);
+        mHSS_PRINTF("CRC32: 0x%x\n", result);
     } else {
-        mHSS_PUTS("Usage:" CRLF
-            "\tcrc32 0x<start_addr> 0x<length>" CRLF
-            CRLF);
+        mHSS_PUTS("Usage:\n"
+            "\tcrc32 0x<start_addr> 0x<length>\n"
+            "\n");
     }
 }
 
@@ -908,12 +931,20 @@ static void tinyCLI_HexDump_(void)
 
         HSS_TinyCLI_HexDump((uint8_t *)hexdump_startAddr, hexdump_count);
     } else {
-        mHSS_PUTS("Usage:" CRLF
-            "\thexdump 0x<start_addr> 0x<length>" CRLF
-            CRLF);
+        mHSS_PUTS("Usage:\n"
+            "\thexdump 0x<start_addr> 0x<length>\n"
+            "\n");
     }
 }
 
+static void tinyCLI_UnsupportedBootMechanism_(char const * const pName)
+{
+    mHSS_PUTS(pName);
+    mHSS_PUTS(" not supported in this build of the HSS.\n"
+              "Supported boot mechanisms:\n");
+    HSS_BootListStorageProviders();
+}
+
 static void tinyCLI_CmdHandler_(int tokenId)
 {
 #if IS_ENABLED(CONFIG_SERVICE_YMODEM)
@@ -963,17 +994,23 @@ static void tinyCLI_CmdHandler_(int tokenId)
         break;
 #endif
 
-#if IS_ENABLED(CONFIG_SERVICE_QSPI) //&& (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_PAYLOAD) || IS_ENABLED(CONFIG_SERVICE_SPI))
     case CMD_QSPI:
+#if IS_ENABLED(CONFIG_SERVICE_QSPI)
         tinyCLI_QSPI_();
-        break;
+#else
+        tinyCLI_UnsupportedBootMechanism_("QSPI");
 #endif
+        break;
 
-#if IS_ENABLED(CONFIG_SERVICE_MMC) && (IS_ENABLED(CONFIG_SERVICE_QSPI) || IS_ENABLED(CONFIG_SERVICE_PAYLOAD) || IS_ENABLED(CONFIG_SERVICE_SPI))
+    case CMD_EMMC:
+        __attribute__((fallthrough)); // deliberate fallthrough
     case CMD_MMC:
+#if IS_ENABLED(CONFIG_SERVICE_MMC)
         HSS_BootSelectMMC();
-        break;
+#else
+        tinyCLI_UnsupportedBootMechanism_("eMMC/SDCard");
 #endif
+        break;
 
 #if IS_ENABLED(CONFIG_SERVICE_PAYLOAD) && (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_QSPI) || IS_ENABLED(CONFIG_SERVICE_SPI))
     case CMD_PAYLOAD:
@@ -981,11 +1018,13 @@ static void tinyCLI_CmdHandler_(int tokenId)
         break;
 #endif
 
-#if defined(CONFIG_SERVICE_SPI) && (defined(CONFIG_SERVICE_MMC) || defined(CONFIG_SERVICE_QSPI) || defined(CONFIG_SERVICE_PAYLOAD))
     case CMD_SPI:
+#if defined(CONFIG_SERVICE_SPI)
         HSS_BootSelectSPI();
-        break;
+#else
+        tinyCLI_UnsupportedBootMechanism_("SPI");
 #endif
+        break;
 
 #if IS_ENABLED(CONFIG_SERVICE_USBDMSC) && (IS_ENABLED(CONFIG_SERVICE_MMC) || IS_ENABLED(CONFIG_SERVICE_QSPI))
     case CMD_USBDMSC:
@@ -1004,14 +1043,14 @@ static void tinyCLI_CmdHandler_(int tokenId)
 #endif
 
     default:
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Unknown command %d (%lu tokens)" CRLF, tokenId, argc_tokenCount);
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Unknown command %d (%lu tokens)\n", tokenId, argc_tokenCount);
         for (index = 1u; index < argc_tokenCount; index++) {
-            mHSS_DEBUG_PRINTF(LOG_NORMAL, "Argument: %s" CRLF, argv_tokenArray[index]);
+            mHSS_DEBUG_PRINTF(LOG_NORMAL, "Argument: %s\n", argv_tokenArray[index]);
         }
         break;
     }
 
-    mHSS_PUTS("" CRLF);
+    mHSS_PUTS("\n");
 }
 
 #if !IS_ENABLED(CONFIG_SERVICE_TINYCLI_REGISTER)
@@ -1024,7 +1063,7 @@ static bool tinyCLI_Getline_(char **pBuffer, size_t *pBufLen)
     status = uart_getline(pBuffer, pBufLen);
 
     if (status < 0) {
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Problem reading input" CRLF);
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Problem reading input\n");
     } else {
         result = true;
     }
@@ -1059,15 +1098,15 @@ void HSS_TinyCLI_Execute(void)
     if (matchFoundFlag) {
         if (commands[cmdIndex].warnIfPostInit && postInit) {
             mHSS_DEBUG_PRINTF(LOG_WARN,
-                "Command %s may cause problems post boot." CRLF
+                "Command %s may cause problems post boot.\n"
                 "Please type it again if you definitely want to execute it"
-                CRLF CRLF, cmdKeys[keyIndex].name);
+                "\n\n", cmdKeys[keyIndex].name);
             commands[cmdIndex].warnIfPostInit = false;
         } else {
             commands[cmdIndex].handler(commands[cmdIndex].tokenId);
         }
     } else {
-        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Unknown command >>%s<<." CRLF CRLF, argv_tokenArray[0]);
+        mHSS_DEBUG_PRINTF(LOG_NORMAL, "Unknown command >>%s<<.\n\n", argv_tokenArray[0]);
     }
 }
 
@@ -1082,13 +1121,13 @@ bool HSS_TinyCLI_Parser(void)
     bool keyPressedFlag = false;
     uint8_t rcv_buf;
 
-    keyPressedFlag = HSS_ShowTimeout("Press a key to enter CLI, ESC to skip" CRLF,
+    keyPressedFlag = HSS_ShowTimeout("Press a key to enter CLI, ESC to skip\n",
         CONFIG_SERVICE_TINYCLI_TIMEOUT, &rcv_buf);
 
     if (!keyPressedFlag) {
-        mHSS_FANCY_PUTS(LOG_NORMAL, "CLI boot interrupt timeout" CRLF);
+        mHSS_FANCY_PUTS(LOG_NORMAL, "CLI boot interrupt timeout\n");
     } else {
-        mHSS_FANCY_PUTS(LOG_NORMAL, "Type HELP for list of commands" CRLF);
+        mHSS_FANCY_PUTS(LOG_NORMAL, "Type HELP for list of commands\n");
         while (!quitFlag) {
 #if !IS_ENABLED(CONFIG_SERVICE_TINYCLI_REGISTER)
             static char *pBuffer = NULL;
