@@ -51,8 +51,8 @@
  * 	set-name: 'PolarFire-SoC-HSS::TestImage'
  * 	hart-entry-points: {u54_1: '0x80200000', u54_2: '0x80200000', u54_3: '0xB0000000', u54_4: '0x80200000'}
  * 	payloads:
- *   	test/baremetal: {exec-addr: '0xB0000000', owner-hart: u54_3, priv-mode: prv_m}
- *   	test/u-boot:    {exec-addr: '0x80200000', owner-hart: u54_1, secondary-hart: u54_2, secondary-hart: u54_4, priv-mode: prv_s, ancilliary-data: test/amp-context-0.dtb}
+ *   	test/baremetal: {exec-addr: '0xB0000000', owner-hart: u54_3, priv-mode: prv_m, payload-name: "baremetal"}
+ *   	test/u-boot:    {exec-addr: '0x80200000', owner-hart: u54_1, secondary-hart: u54_2, secondary-hart: u54_4, priv-mode: prv_s, ancilliary-data: test/amp-context-0.dtb, payload-name: "Yocto (U-Boot)"}
  */
 
 /////////////////////////////////////////////////////////////////////////////
@@ -85,8 +85,11 @@ enum token
 	TOKEN_PAYLOAD_EXEC_ADDR,
 	TOKEN_PAYLOAD_OWNER_HART,
 	TOKEN_PAYLOAD_SECONDARY_HART,
+	TOKEN_PAYLOAD_PAYLOAD_NAME,
 	TOKEN_PAYLOAD_PRIV_MODE,
 	TOKEN_PAYLOAD_SKIP_OPENSBI,
+	TOKEN_PAYLOAD_ALLOW_REBOOT,
+	TOKEN_PAYLOAD_SKIP_AUTOBOOT,
 	TOKEN_PAYLOAD_ANCILLIARY_DATA,
 	TOKEN_PRIV_MODE_M,
 	TOKEN_PRIV_MODE_H,
@@ -95,7 +98,9 @@ enum token
 	TOKEN_HART_U54_1,
 	TOKEN_HART_U54_2,
 	TOKEN_HART_U54_3,
-	TOKEN_HART_U54_4
+	TOKEN_HART_U54_4,
+	TOKEN_REBOOT_COLD,
+	TOKEN_REBOOT_WARM,
 };
 
 struct hss_config_token
@@ -110,9 +115,12 @@ const struct hss_config_token tokens[] = {
 	{ TOKEN_PAYLOADS,			"payloads" },
 	{ TOKEN_PAYLOAD_EXEC_ADDR,		"exec-addr" },
 	{ TOKEN_PAYLOAD_OWNER_HART,		"owner-hart" },
-	{ TOKEN_PAYLOAD_SECONDARY_HART,		"secondary-hart" },
+	{ TOKEN_PAYLOAD_PAYLOAD_NAME,		"payload-name" },
 	{ TOKEN_PAYLOAD_PRIV_MODE,		"priv-mode" },
+	{ TOKEN_PAYLOAD_SECONDARY_HART,		"secondary-hart" },
 	{ TOKEN_PAYLOAD_SKIP_OPENSBI,		"skip-opensbi" },
+	{ TOKEN_PAYLOAD_ALLOW_REBOOT,		"allow-reboot" },
+	{ TOKEN_PAYLOAD_SKIP_AUTOBOOT,		"skip-autoboot" },
 	{ TOKEN_PAYLOAD_ANCILLIARY_DATA,	"ancilliary-data" },
 	{ TOKEN_PRIV_MODE_M,			"prv_m" },
 	{ TOKEN_PRIV_MODE_S,			"prv_s" },
@@ -120,7 +128,9 @@ const struct hss_config_token tokens[] = {
 	{ TOKEN_HART_U54_1,			"u54_1" },
 	{ TOKEN_HART_U54_2,			"u54_2" },
 	{ TOKEN_HART_U54_3,			"u54_3" },
-	{ TOKEN_HART_U54_4,			"u54_4" }
+	{ TOKEN_HART_U54_4,			"u54_4" },
+	{ TOKEN_REBOOT_COLD,			"cold" },
+	{ TOKEN_REBOOT_WARM,			"warm" }
 };
 
 enum ParserState
@@ -139,9 +149,12 @@ enum ParserState
 	STATE_NEW_PAYLOAD,
 	STATE_NEW_PAYLOAD_EXEC_ADDR,
 	STATE_NEW_PAYLOAD_OWNER_HART,
-	STATE_NEW_PAYLOAD_SECONDARY_HART,
+	STATE_NEW_PAYLOAD_PAYLOAD_NAME,
 	STATE_NEW_PAYLOAD_PRIV_MODE,
+	STATE_NEW_PAYLOAD_SECONDARY_HART,
 	STATE_NEW_PAYLOAD_SKIP_OPENSBI,
+	STATE_NEW_PAYLOAD_ALLOW_REBOOT,
+	STATE_NEW_PAYLOAD_SKIP_AUTOBOOT,
 	STATE_NEW_PAYLOAD_ANCILLIARY_DATA,
 };
 
@@ -161,9 +174,12 @@ const char * const stateNames[] =
 	[ STATE_NEW_PAYLOAD ] =			"STATE_NEW_PAYLOAD",
 	[ STATE_NEW_PAYLOAD_EXEC_ADDR ] =	"STATE_NEW_PAYLOAD_EXEC_ADDR",
 	[ STATE_NEW_PAYLOAD_OWNER_HART ] =	"STATE_NEW_PAYLOAD_OWNER_HART",
-	[ STATE_NEW_PAYLOAD_SECONDARY_HART ] =	"STATE_NEW_PAYLOAD_SECONDARY_HART",
+	[ STATE_NEW_PAYLOAD_PAYLOAD_NAME ] =	"STATE_NEW_PAYLOAD_PAYLOAD_NAME",
 	[ STATE_NEW_PAYLOAD_PRIV_MODE ] =	"STATE_NEW_PAYLOAD_PRIV_MODE",
+	[ STATE_NEW_PAYLOAD_SECONDARY_HART ] =	"STATE_NEW_PAYLOAD_SECONDARY_HART",
 	[ STATE_NEW_PAYLOAD_SKIP_OPENSBI ] =	"STATE_NEW_PAYLOAD_SKIP_OPENSBI",
+	[ STATE_NEW_PAYLOAD_ALLOW_REBOOT ] =	"STATE_NEW_PAYLOAD_ALLOW_REBOOT",
+	[ STATE_NEW_PAYLOAD_SKIP_AUTOBOOT ] =	"STATE_NEW_PAYLOAD_SKIP_AUTOBOOT",
 	[ STATE_NEW_PAYLOAD_ANCILLIARY_DATA ] =	"STATE_NEW_PAYLOAD_ANCILLIARY_DATA",
 };
 
@@ -200,9 +216,12 @@ static void Handle_STATE_PAYLOAD_MAPPINGS(yaml_event_t *pEvent)			__attribute__(
 static void Handle_STATE_NEW_PAYLOAD(yaml_event_t *pEvent)			__attribute__((nonnull));
 static void Handle_STATE_NEW_PAYLOAD_EXEC_ADDR(yaml_event_t *pEvent)		__attribute__((nonnull));
 static void Handle_STATE_NEW_PAYLOAD_OWNER_HART(yaml_event_t *pEvent)		__attribute__((nonnull));
-static void Handle_STATE_NEW_PAYLOAD_SECONDARY_HART(yaml_event_t *pEvent)	__attribute__((nonnull));
+static void Handle_STATE_NEW_PAYLOAD_PAYLOAD_NAME(yaml_event_t *pEvent)		__attribute__((nonnull));
 static void Handle_STATE_NEW_PAYLOAD_PRIV_MODE(yaml_event_t *pEvent)		__attribute__((nonnull));
+static void Handle_STATE_NEW_PAYLOAD_SECONDARY_HART(yaml_event_t *pEvent)	__attribute__((nonnull));
 static void Handle_STATE_NEW_PAYLOAD_SKIP_OPENSBI(yaml_event_t *pEvent)		__attribute__((nonnull));
+static void Handle_STATE_NEW_PAYLOAD_ALLOW_REBOOT(yaml_event_t *pEvent)		__attribute__((nonnull));
+static void Handle_STATE_NEW_PAYLOAD_SKIP_AUTOBOOT(yaml_event_t *pEvent)	__attribute__((nonnull));
 static void Handle_STATE_NEW_PAYLOAD_ANCILLIARY_DATA(yaml_event_t *pEvent)	__attribute__((nonnull));
 
 /////////////////////////////////////////////////////////////////////////////
@@ -230,9 +249,12 @@ static struct StateHandler stateHandler[] = {
 	{ STATE_NEW_PAYLOAD,			Handle_STATE_NEW_PAYLOAD },
 	{ STATE_NEW_PAYLOAD_EXEC_ADDR,		Handle_STATE_NEW_PAYLOAD_EXEC_ADDR },
 	{ STATE_NEW_PAYLOAD_OWNER_HART,		Handle_STATE_NEW_PAYLOAD_OWNER_HART },
-	{ STATE_NEW_PAYLOAD_SECONDARY_HART,	Handle_STATE_NEW_PAYLOAD_SECONDARY_HART },
+	{ STATE_NEW_PAYLOAD_PAYLOAD_NAME,	Handle_STATE_NEW_PAYLOAD_PAYLOAD_NAME },
 	{ STATE_NEW_PAYLOAD_PRIV_MODE,		Handle_STATE_NEW_PAYLOAD_PRIV_MODE },
+	{ STATE_NEW_PAYLOAD_SECONDARY_HART,	Handle_STATE_NEW_PAYLOAD_SECONDARY_HART },
 	{ STATE_NEW_PAYLOAD_SKIP_OPENSBI,	Handle_STATE_NEW_PAYLOAD_SKIP_OPENSBI },
+	{ STATE_NEW_PAYLOAD_ALLOW_REBOOT,	Handle_STATE_NEW_PAYLOAD_ALLOW_REBOOT },
+	{ STATE_NEW_PAYLOAD_SKIP_AUTOBOOT,	Handle_STATE_NEW_PAYLOAD_SKIP_AUTOBOOT },
 	{ STATE_NEW_PAYLOAD_ANCILLIARY_DATA,	Handle_STATE_NEW_PAYLOAD_ANCILLIARY_DATA },
 };
 
@@ -623,13 +645,18 @@ static void Handle_STATE_HART_ENTRY_POINTS_U54_4(yaml_event_t *pEvent)
 }
 
 static char base_name[BOOT_IMAGE_MAX_NAME_LEN];
+static char payload_name[BOOT_IMAGE_MAX_NAME_LEN];
 static uintptr_t base_exec_addr = 0u;
 static size_t base_owner = 0u;
 static size_t base_secondary[3] = { 0u, 0u, 0u };
 static uint8_t base_priv_mode = PRV_ILLEGAL;
 static size_t secondary_idx = 0u;
+
 static bool ancilliary_data_present_flag = false;
 static bool skip_opensbi_flag = false;
+static bool skip_autoboot_flag = false;
+static bool allow_cold_reboot_flag = false;
+static bool allow_warm_reboot_flag = false;
 static char ancilliary_name[BOOT_IMAGE_MAX_NAME_LEN];
 
 static void Handle_STATE_PAYLOAD_MAPPINGS(yaml_event_t *pEvent)
@@ -648,6 +675,7 @@ static void Handle_STATE_PAYLOAD_MAPPINGS(yaml_event_t *pEvent)
 		debug_printf(0, "Parsing payload >>%s<<\n", pEvent->data.scalar.value);
 
 		strncpy(base_name, (char *)pEvent->data.scalar.value, BOOT_IMAGE_MAX_NAME_LEN-2);
+                payload_name[0] = '\0';
 		base_name[BOOT_IMAGE_MAX_NAME_LEN-1] = '\0';
 
 		base_exec_addr = 0u;
@@ -657,8 +685,12 @@ static void Handle_STATE_PAYLOAD_MAPPINGS(yaml_event_t *pEvent)
 		base_secondary[1] = 0u;
 		base_secondary[2] = 0u;
 		base_priv_mode = PRV_M;
+
 		ancilliary_data_present_flag = false;
 		skip_opensbi_flag = false;
+		allow_cold_reboot_flag = false;
+		allow_warm_reboot_flag = false;
+		skip_autoboot_flag = false;
 
 		Do_State_Transition(STATE_NEW_PAYLOAD);
 		break;
@@ -678,11 +710,30 @@ static void Handle_STATE_NEW_PAYLOAD(yaml_event_t *pEvent)
 
 	switch (pEvent->type) {
 	case YAML_MAPPING_START_EVENT:
+		base_owner = 0u;
 		break;
 
 	case YAML_MAPPING_END_EVENT:
 		if (!override_set_name_flag) {
-			concatenate(bootImage.set_name, base_name, ARRAY_SIZE(bootImage.set_name));
+			if (strlen(payload_name)) {
+				concatenate(bootImage.set_name, payload_name, ARRAY_SIZE(bootImage.set_name));
+			} else {
+				concatenate(bootImage.set_name, base_name, ARRAY_SIZE(bootImage.set_name));
+			}
+		}
+
+		assert(base_owner);
+		if (strlen(bootImage.hart[base_owner-1].name)) {
+			concatenate(bootImage.hart[base_owner-1].name, "+",
+					ARRAY_SIZE(bootImage.hart[base_owner-1].name));
+		}
+
+		if (strlen(payload_name)) {
+			concatenate(bootImage.hart[base_owner-1].name, payload_name,
+					ARRAY_SIZE(bootImage.hart[base_owner-1].name));
+		} else {
+			concatenate(bootImage.hart[base_owner-1].name, base_name,
+					ARRAY_SIZE(bootImage.hart[base_owner-1].name));
 		}
 
 		bool retVal = elf_parser(base_name, base_owner);
@@ -719,15 +770,29 @@ static void Handle_STATE_NEW_PAYLOAD(yaml_event_t *pEvent)
 			Do_State_Transition(STATE_NEW_PAYLOAD_SECONDARY_HART);
 			break;
 
+		case TOKEN_PAYLOAD_PAYLOAD_NAME:
+			Do_State_Transition(STATE_NEW_PAYLOAD_PAYLOAD_NAME);
+			break;
+
 		case TOKEN_PAYLOAD_PRIV_MODE:
 			Do_State_Transition(STATE_NEW_PAYLOAD_PRIV_MODE);
 			break;
 
 		case TOKEN_PAYLOAD_SKIP_OPENSBI:
-			debug_printf(1, "\tskipping OpenSBI for this payload\n");
+			debug_printf(1, "\tskipping OpenSBI for this context\n");
 			Do_State_Transition(STATE_NEW_PAYLOAD_SKIP_OPENSBI);
 			break;
 
+		case TOKEN_PAYLOAD_SKIP_AUTOBOOT:
+			debug_printf(1, "\tskipping autoboot for this payload\n");
+			Do_State_Transition(STATE_NEW_PAYLOAD_SKIP_AUTOBOOT);
+			break;
+
+		case TOKEN_PAYLOAD_ALLOW_REBOOT:
+			debug_printf(1, "\tallow reboot for this context\n");
+			Do_State_Transition(STATE_NEW_PAYLOAD_ALLOW_REBOOT);
+			break;
+
 		case TOKEN_PAYLOAD_ANCILLIARY_DATA:
 			debug_printf(1, "\tancilliary data found\n");
 			ancilliary_data_present_flag = true;
@@ -799,13 +864,6 @@ static void Handle_STATE_NEW_PAYLOAD_OWNER_HART(yaml_event_t *pEvent)
 			// deliberate fallthrough
 		case TOKEN_HART_U54_4:
 			base_owner = (token_idx - TOKEN_HART_U54_1 + 1u);
-
-			if (strlen(bootImage.hart[base_owner-1].name)) {
-				concatenate(bootImage.hart[base_owner-1].name, "+", ARRAY_SIZE(bootImage.hart[base_owner-1].name));
-			}
-
-			concatenate(bootImage.hart[base_owner-1].name, base_name, ARRAY_SIZE(bootImage.hart[base_owner-1].name));
-
 			debug_printf(1, "\towner is %" PRIu64 "\n", base_owner);
 			Do_State_Transition(STATE_NEW_PAYLOAD);
 			break;
@@ -882,6 +940,18 @@ static void populate_boot_flags(void)
 		flags |= BOOT_FLAG_SKIP_OPENSBI;
 	}
 
+	if (allow_cold_reboot_flag) {
+		// cold reboot implies warm reboot also allowed
+		flags |= BOOT_FLAG_ALLOW_COLD_REBOOT;
+		flags |= BOOT_FLAG_ALLOW_WARM_REBOOT;
+	} else if (allow_warm_reboot_flag) {
+		flags |= BOOT_FLAG_ALLOW_WARM_REBOOT;
+	}
+
+	if (skip_autoboot_flag) {
+		flags |= BOOT_FLAG_SKIP_AUTOBOOT;
+	}
+
 	bootImage.hart[base_owner-1].flags = flags;
 
 	for (size_t i = 0u; i < ARRAY_SIZE(base_secondary); i++) {
@@ -891,6 +961,35 @@ static void populate_boot_flags(void)
 	}
 }
 
+static void Handle_STATE_NEW_PAYLOAD_PAYLOAD_NAME(yaml_event_t *pEvent)
+{
+	assert(pEvent);
+
+	switch (pEvent->type) {
+	case YAML_MAPPING_START_EVENT:
+		assert(0==1);
+		Do_State_Transition(STATE_MAPPING);
+		break;
+
+	case YAML_MAPPING_END_EVENT:
+		assert(0==1);
+		Do_State_Transition(STATE_MAPPING);
+		break;
+
+	case YAML_SCALAR_EVENT:
+		strncpy(payload_name, (char *)pEvent->data.scalar.value, BOOT_IMAGE_MAX_NAME_LEN-2);
+		payload_name[BOOT_IMAGE_MAX_NAME_LEN-1] = '\0';
+		override_set_name_flag = true;
+		Do_State_Transition(STATE_NEW_PAYLOAD);
+		break;
+
+	default:
+		report_illegal_event(stateNames[parser_state], pEvent);
+		exit(EXIT_FAILURE);
+		break;
+	}
+}
+
 static void Handle_STATE_NEW_PAYLOAD_PRIV_MODE(yaml_event_t *pEvent)
 {
 	assert(pEvent);
@@ -960,12 +1059,13 @@ static void Handle_STATE_NEW_PAYLOAD_SKIP_OPENSBI(yaml_event_t *pEvent)
                 break;
 
         case YAML_MAPPING_END_EVENT:
+		assert(0 == 1);
                 Do_State_Transition(STATE_MAPPING);
                 break;
 
         case YAML_SCALAR_EVENT:
 		if (!strncasecmp((char *)pEvent->data.scalar.value, "true", 4)) {
-			value = 1;
+			value = 1u;
 		} else {
 			value = (uint8_t)strtoul((char *)pEvent->data.scalar.value, NULL, 0);
 		}
@@ -983,7 +1083,78 @@ static void Handle_STATE_NEW_PAYLOAD_SKIP_OPENSBI(yaml_event_t *pEvent)
         }
 }
 
+static void Handle_STATE_NEW_PAYLOAD_ALLOW_REBOOT(yaml_event_t *pEvent)
+{
+        assert(pEvent);
 
+        enum token token_idx = TOKEN_UNKNOWN;
+
+        switch (pEvent->type) {
+        case YAML_MAPPING_START_EVENT:
+                break;
+
+        case YAML_MAPPING_END_EVENT:
+                Do_State_Transition(STATE_MAPPING);
+                break;
+
+        case YAML_SCALAR_EVENT:
+                token_idx = string_to_scalar(pEvent->data.scalar.value);
+                switch (token_idx) {
+                case TOKEN_REBOOT_WARM:
+			allow_warm_reboot_flag = true;
+                        break;
+
+                case TOKEN_REBOOT_COLD:
+			allow_cold_reboot_flag = true;
+                        break;
+
+                default:
+                        report_illegal_token(stateNames[parser_state], pEvent);
+                        exit(EXIT_FAILURE);
+                        break;
+                }
+		Do_State_Transition(STATE_NEW_PAYLOAD);
+                break;
+
+        default:
+                report_illegal_event(stateNames[parser_state], pEvent);
+                exit(EXIT_FAILURE);
+                break;
+        }
+}
+
+static void Handle_STATE_NEW_PAYLOAD_SKIP_AUTOBOOT(yaml_event_t *pEvent)
+{
+        assert(pEvent);
+	uint8_t value;
+
+        switch (pEvent->type) {
+        case YAML_MAPPING_START_EVENT:
+                break;
+
+        case YAML_MAPPING_END_EVENT:
+                Do_State_Transition(STATE_MAPPING);
+                break;
+
+        case YAML_SCALAR_EVENT:
+		if (!strncasecmp((char *)pEvent->data.scalar.value, "true", 4)) {
+			value = 1;
+		} else {
+			value = (uint8_t)strtoul((char *)pEvent->data.scalar.value, NULL, 0);
+		}
+
+                if (value) {
+			skip_autoboot_flag = true;
+		}
+		Do_State_Transition(STATE_NEW_PAYLOAD);
+                break;
+
+        default:
+                report_illegal_event(stateNames[parser_state], pEvent);
+                exit(EXIT_FAILURE);
+                break;
+        }
+}
 
 static void Handle_STATE_NEW_PAYLOAD_ANCILLIARY_DATA(yaml_event_t *pEvent)
 {
